import{S as p}from"./Sidebar.8cf12d2b.js";import{N as m}from"./Navbar.31374668.js";import{F as l,G as u,H as _}from"./icons.3f47812d.js";import{d as b,K as f,b as g,c as v,e as t,z as s,x as r,w as y,F as h,J as w,a as z,O as I,Q as O,q as x}from"./registerWidgets.bbbd3e16.js";import{a as S}from"./asyncComputed.ad67be0e.js";import"./gateway.d8ce80c3.js";import{O as k}from"./organization.c2f79436.js";import"./Tooltip.8e5ed40c.js";import"./logo.084e5d7c.js";import"./passwordlessManager.2d127f26.js";import"./activeRecord.9842b68f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="cd139793-bb6d-420d-9505-506b44c5f026",e._sentryDebugIdIdentifier="sentry-dbid-cd139793-bb6d-420d-9505-506b44c5f026")}catch{}})();const B=e=>(I("data-v-580769d7"),e=e(),O(),e),C={class:"organization"},D=B(()=>r("div",null,"div",-1)),N=b({__name:"Organization",setup(e){const n=w().params.organizationId,{result:a}=S(()=>k.get(n)),i=f(()=>a.value?[{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),d=[{name:"Organization",items:[{name:"Projects",icon:l,path:"projects"},{name:"Members",icon:u,path:"members"},{name:"Billing",icon:_,path:"billing",unavailable:!0}]}];return(F,j)=>{const c=z("router-view");return g(),v(h,null,[t(m,{breadcrumb:s(i)},null,8,["breadcrumb"]),r("div",C,[t(p,{class:"sidebar",sections:s(d)},{default:y(()=>[D]),_:1},8,["sections"]),t(c)])],64)}}});const $=x(N,[["__scopeId","data-v-580769d7"]]);export{$ as default};
//# sourceMappingURL=Organization.a62a58b9.js.map
