import{q as t,b as s,c as a}from"./registerWidgets.7cf0d33e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="b8db13b3-9751-40aa-a68a-d6565bd80466",e._sentryDebugIdIdentifier="sentry-dbid-b8db13b3-9751-40aa-a68a-d6565bd80466")}catch{}})();const d={},o={class:"organization-settings"};function r(e,n){return s(),a("div",o,"Organization settings")}const b=t(d,[["render",r]]);export{b as default};
//# sourceMappingURL=OrganizationSettings.7402d8dd.js.map
