import{q as r,a,b as i,t as c,f as d,g as p,_,h as u,k as l,T as h,P as f,C as b,M as g,s as y,i as m,j as s,l as w,m as v,n as k}from"./registerWidgets.0a925ff6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="8519dc3e-886d-4ba8-b061-51d4c9dc5128",e._sentryDebugIdIdentifier="sentry-dbid-8519dc3e-886d-4ba8-b061-51d4c9dc5128")}catch{}})();const I={};function x(e,t){const o=a("router-view");return i(),c(o,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=r(I,[["render",x]]),n=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.af3627ec.js"),["assets/Player.af3627ec.js","assets/index.665bc3dc.js","assets/registerWidgets.0a925ff6.js","assets/registerWidgets.448db7e9.css","assets/log.b73caccb.js","assets/broker.ff33ed68.js","assets/passwordlessManager.ab5003b1.js","assets/icons.d9ce72d6.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.cdf74f91.js","assets/Passwordless.0888f9cc.js","assets/CircularLoading.63d322f4.js","assets/lottie.a6ae83a3.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/executeJs.2b64d7d8.js","assets/PlayerNavbar.82105838.js","assets/PlayerNavbar.b27e2024.css","assets/WidgetsFrame.3dc21625.js","assets/colors.b1b4c57b.js","assets/WidgetsFrame.701a818b.css","assets/Modal.373fa9f4.js","assets/Modal.5aaf8eba.css","assets/executeJs.b0d1ede9.css","assets/broker.f87ad36d.css","assets/DashPlayer.b23cd495.js","assets/runnerData.cb7dff48.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.57718c9c.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=u({render:()=>l(A)});h.init(),e.use(n),e.use(f),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",g),e.component("Message",y),m(e,n),s(e,w),s(e,v),s(e,k)};D();
//# sourceMappingURL=player.d4494a5e.js.map
