import{d as b,K as f,b as y,t as g,z as s,J as _}from"./registerWidgets.9f96e537.js";import{a as w}from"./asyncComputed.0a45b9d8.js";import"./gateway.052cd6ee.js";import{M as i}from"./member.0995ac01.js";import{C as I}from"./CrudView.d07bbb18.js";import"./passwordlessManager.5f237f08.js";import"./activeRecord.81c11d03.js";import"./DropdownMenu.b6bcdf3a.js";import"./Modal.add412a5.js";import"./LoadingIndicator.c4c6ba20.js";import"./lottie.2c3db159.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="2a699cb4-a955-42dc-8ef9-1c56ea456cd0",e._sentryDebugIdIdentifier="sentry-dbid-2a699cb4-a955-42dc-8ef9-1c56ea456cd0")}catch{}})();const A=b({__name:"Members",setup(e){const o=_().params.organizationId,m=[{key:"email",label:"Email"}],l=async t=>{await i.create(o,t.email),p()},{loading:c,result:d,refetch:p}=w(()=>i.list(o)),u=f(()=>{var t,r;return{columns:[{name:"Email"},{name:"Role"}],rows:(r=(t=d.value)==null?void 0:t.map(n=>({key:n.email,cells:[{text:n.email,classes:["title","centered"]},{text:n.role,classes:["centered"]}]})))!=null?r:[]}});return(t,r)=>(y(),g(I,{"entity-name":"members",loading:s(c),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:s(u),"create-button-text":"Add members",fields:m,onCreate:l},null,8,["loading","table"]))}});export{A as default};
//# sourceMappingURL=Members.c938a7ab.js.map
