import{R as c,K as t}from"./registerWidgets.0e006b6f.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="a56ef82e-aeb2-4854-a677-4b496e4a4456",r._sentryDebugIdIdentifier="sentry-dbid-a56ef82e-aeb2-4854-a677-4b496e4a4456")}catch{}})();const i=r=>{const e=c({loading:!0,result:null,error:null}),n=l=>(e.value={loading:!1,result:l,error:null},l),a=l=>{e.value={loading:!1,result:null,error:l}},o=()=>{e.value={loading:!0,result:null,error:null},r().then(n).catch(a)};o();const s=t(()=>e.value.loading),u=t(()=>e.value.result),d=t(()=>e.value.error);return{loading:s,result:u,error:d,refetch:o}};export{i as a};
//# sourceMappingURL=asyncComputed.62aacf33.js.map
