import{P as r}from"./Passwordless.e6779d6e.js";import{N as a}from"./Navbar.eac3ae22.js";import{d as c,b as i,c as d,e as t,H as _,q as p}from"./registerWidgets.80830a62.js";import{M as m}from"./member.601c685a.js";import"./CircularLoading.dfc9e798.js";import"./lottie.ab5349ef.js";import"./icons.96376736.js";import"./passwordlessManager.65c1d475.js";import"./logo.084e5d7c.js";import"./asyncComputed.7fd138fd.js";import"./gateway.0f7f822d.js";import"./activeRecord.dd1973bd.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="6bc2024c-a588-4f44-a896-131e29e41c4a",e._sentryDebugIdIdentifier="sentry-dbid-6bc2024c-a588-4f44-a896-131e29e41c4a")}catch{}})();const f={class:"login"},l=c({__name:"Login",setup(e){const o=_();async function s(n){await m.login(),o.push({name:"home"})}return(n,u)=>(i(),d("div",f,[t(a,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const N=p(l,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.515bfd10.js.map
