import{d as k,r as g,G as C,b as s,c as a,A as N,v as c,H as x,z as D,y,q as f,F as h,J as S,K as T,L,E as $,e as i,I as B,B as d,t as O,w as A,N as F,O as R,a as z}from"./registerWidgets.fff064a1.js";import{d as E,s as V,w as W,a as q,b as H,c as J}from"./icons.b8ff2c28.js";const j={class:"text"},G=k({__name:"Tooltip",props:{text:{type:String,required:!0},left:{type:Number},top:{type:Number},fixed:{type:Boolean,default:!1}},setup(n){const o=n,_=g(Date.now()),l=()=>{_.value=Date.now()},p=g(null),v=()=>{var e,b,w;const t=(e=p.value)==null?void 0:e.getBoundingClientRect();if(!t)return{};const{x:m,y:r}=t;return _.value,{position:"fixed",top:`${r+((b=o.top)!=null?b:0)}px`,left:`${m+((w=o.left)!=null?w:0)}px`}},u=C(()=>{var t;return o.fixed?v():{left:`${(t=o.left)!=null?t:-14}px`,...o.top?{top:`${o.top}px`}:{}}});return(t,m)=>(s(),a("div",{ref_key:"tooltipBox",ref:p,class:"tooltip-box",onMouseenter:l},[N(t.$slots,"default",{},void 0,!0),c("div",{class:"tooltip",style:D(y(u))},[c("span",j,x(n.text),1)],4)],544))}});const K=f(G,[["__scopeId","data-v-74636348"]]),M={class:"sidebar"},P={class:"section-name"},U=["onClick"],Q={class:"item-name"},X={key:0,class:"tag soon"},Y={key:1,class:"tag beta"},Z={key:2,class:"tag cloud"},ee=k({__name:"Sidebar",setup(n){var u;const o=T(),_=L(),l=g((u=_.name)!=null?u:"forms"),p=C(()=>[{name:"Runtime",items:[{name:"Forms",icon:E,path:"forms"},{name:"Jobs",icon:V,path:"jobs",cloud:!0},{name:"Hooks",icon:W,path:"hooks"},{name:"Dashes",icon:q,path:"dashes",beta:!0}]},{name:"Settings",items:[{name:"Settings",icon:H,path:"settings"}]}]),v=t=>{t.unavailable||(o.push(t.path),l.value=t.path)};return(t,m)=>(s(),a("div",M,[(s(!0),a(h,null,S(y(p),r=>(s(),a("div",{key:r.name,class:"section"},[c("span",P,x(r.name),1),(s(!0),a(h,null,S(r.items,e=>(s(),a("div",{key:e.name,role:"button",class:$(["item",{active:l.value===e.path,disabled:e.unavailable||r.cloud}]),tabindex:"0",onClick:b=>v(e)},[i(B,{class:$(["icon",{disabled:e.unavailable,active:l.value===e.path}]),path:e.icon,width:"20",height:"20"},null,8,["class","path"]),c("span",Q,x(e.name),1),e.unavailable?(s(),a("span",X,"SOON")):d("",!0),e.beta?(s(),a("span",Y,"BETA")):d("",!0),e.cloud?(s(),a("span",Z,"CLOUD")):d("",!0),e.warning?(s(),O(K,{key:3,class:"warning",text:e.warning,fixed:!0,top:18,left:18},{default:A(()=>[i(B,{path:y(J),fill:"#D35249",width:"20",height:"20"},null,8,["path"])]),_:2},1032,["text"])):d("",!0)],10,U))),128))]))),128))]))}});const te=f(ee,[["__scopeId","data-v-641517f2"]]),se="/assets/logo.0faadfa2.svg";const ae={},I=n=>(F("data-v-59b2e704"),n=n(),R(),n),oe=I(()=>c("img",{class:"logo",src:se,alt:"Abstra cloud logo"},null,-1)),ne=I(()=>c("span",null," Abstra ",-1));function ce(n,o){return s(),a(h,null,[oe,ne],64)}const le=f(ae,[["render",ce],["__scopeId","data-v-59b2e704"]]),re={class:"workspace"},_e=k({__name:"Workspace",setup(n){return(o,_)=>{const l=z("router-view");return s(),a(h,null,[c("nav",null,[i(le)]),c("div",re,[i(te,{class:"sidebar"}),i(l,{class:"view"})])],64)}}});const ue=f(_e,[["__scopeId","data-v-b590474e"]]);export{ue as default};
//# sourceMappingURL=Workspace.9e3a8205.js.map
