import{d as o,b as a,c,q as d}from"./registerWidgets.553de467.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="0fa378f0-380d-42f7-90b0-2f79450a0df4",e._sentryDebugIdIdentifier="sentry-dbid-0fa378f0-380d-42f7-90b0-2f79450a0df4")}catch{}})();const f=["href"],_=o({__name:"DocsButton",props:{path:null},setup(e){return(t,n)=>{var s;return a(),c("a",{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank"}," Docs ",8,f)}}});const u=d(_,[["__scopeId","data-v-9fec5678"]]);export{u as D};
//# sourceMappingURL=DocsButton.138f3a00.js.map
