import{S as d}from"./Sidebar.4198cf64.js";import{N as m}from"./Navbar.37cfe3a8.js";import{F as p,G as l,H as u}from"./icons.6bb7a228.js";import{d as _,K as b,b as f,c as g,e as t,z as r,x as v,F as y,J as z,a as w,q as I}from"./registerWidgets.0e006b6f.js";import{a as h}from"./asyncComputed.62aacf33.js";import"./gateway.68890283.js";import{O}from"./organization.4aa59dca.js";import"./index.699f7fd0.js";import"./Tooltip.efeb9f49.js";import"./logo.084e5d7c.js";import"./passwordlessManager.4cf24a2b.js";import"./pubsub.13db2123.js";import"./activeRecord.d399634f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="42f321ed-54a6-4cbc-93c6-499ed74ccd4c",e._sentryDebugIdIdentifier="sentry-dbid-42f321ed-54a6-4cbc-93c6-499ed74ccd4c")}catch{}})();const x={class:"organization"},k=_({__name:"Organization",setup(e){const n=z().params.organizationId,{result:a}=h(()=>O.get(n)),s=b(()=>a.value?[{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),i=[{name:"Organization",items:[{name:"Projects",icon:p,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(B,D)=>{const c=w("router-view");return f(),g(y,null,[t(m,{breadcrumb:r(s)},null,8,["breadcrumb"]),v("div",x,[t(d,{class:"sidebar",sections:r(i)},null,8,["sections"]),t(c)])],64)}}});const P=I(k,[["__scopeId","data-v-7eef90b7"]]);export{P as default};
//# sourceMappingURL=Organization.af762df3.js.map
