import{x as a}from"./icons.f7969917.js";import{d as c,a as r,b as d,c as i,e as _,z as f,S as l,q as u}from"./registerWidgets.726232df.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="18d048bf-cf2b-4155-9fc9-0be74039dc36",e._sentryDebugIdIdentifier="sentry-dbid-18d048bf-cf2b-4155-9fc9-0be74039dc36")}catch{}})();const b=c({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const s=r("icon");return d(),i("button",{class:"back-btn",onClick:n[0]||(n[0]=p=>t("exitFullscreenPreview"))},[_(s,{class:"icon",path:f(a),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),l(" Editor ")])}}});const w=u(b,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.cc22a97e.js.map
