import{d as f,K as b,b as y,t as g,z as s,J as _}from"./registerWidgets.0a925ff6.js";import{a as w}from"./asyncComputed.57718c9c.js";import"./gateway.2d990259.js";import{M as i}from"./member.55112495.js";import"./index.bc596894.js";import{C as I}from"./CrudView.36f4723a.js";import"./passwordlessManager.ab5003b1.js";import"./activeRecord.ffa40c01.js";import"./DropdownMenu.55337a35.js";import"./Modal.373fa9f4.js";import"./LoadingIndicator.1acdfc35.js";import"./lottie.a6ae83a3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="615ea839-7804-4ed2-a338-ae437df75a69",e._sentryDebugIdIdentifier="sentry-dbid-615ea839-7804-4ed2-a338-ae437df75a69")}catch{}})();const J=f({__name:"Members",setup(e){const o=_().params.organizationId,m=[{key:"email",label:"Email"}],l=async t=>{await i.create(o,t.email),p()},{loading:d,result:c,refetch:p}=w(()=>i.list(o)),u=b(()=>{var t,r;return{columns:[{name:"Email"},{name:"Role"}],rows:(r=(t=c.value)==null?void 0:t.map(n=>({key:n.email,cells:[{text:n.email,classes:["title","centered"]},{text:n.role,classes:["centered"]}]})))!=null?r:[]}});return(t,r)=>(y(),g(I,{"entity-name":"members",loading:s(d),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:s(u),"create-button-text":"Add members",fields:m,onCreate:l},null,8,["loading","table"]))}});export{J as default};
//# sourceMappingURL=Members.8d761096.js.map
