import{u as n}from"./registerWidgets.88d12ae1.js";import{p as a}from"./passwordlessManager.a5c71e7e.js";const r=n("cloud-api");class d{static async get(t){const o=await(await fetch(`${r}/console/${t}`,{headers:{...a.getUserHeaders("Author-Authorization")}})).text();return o?JSON.parse(o):null}static async post(t,s){const e=await(await fetch(`${r}/console/${t}`,{method:"POST",headers:{"Content-Type":"application/json",...a.getUserHeaders("Author-Authorization")},body:JSON.stringify(s)})).text();return e?JSON.parse(e):null}static async patch(t,s){const e=await(await fetch(`${r}/console/${t}`,{method:"PATCH",headers:{"Content-Type":"application/json",...a.getUserHeaders("Author-Authorization")},body:JSON.stringify(s)})).text();return e?JSON.parse(e):null}static async delete(t){await fetch(`${r}/console/${t}`,{method:"DELETE",headers:{"Content-Type":"application/json",...a.getUserHeaders("Author-Authorization")}})}}export{d as C};
//# sourceMappingURL=gateway.042591ee.js.map
