import{M as a}from"./Modal.654099b6.js";import{d as r,v as c,r as d,b as _,c as l,e as n,w as f,F as i,a as m,x as u,q as p}from"./registerWidgets.1590c05e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="ac84acb1-6091-4c57-a18b-9f2d76c1808c",e._sentryDebugIdIdentifier="sentry-dbid-ac84acb1-6091-4c57-a18b-9f2d76c1808c")}catch{}})();const b=["src"],y=r({__name:"Home",setup(e){const o=c({onboardingForm:""}),t=d(null);return(g,v)=>{const s=m("router-view");return _(),l(i,null,[n(s,{class:"router"}),n(a,{ref_key:"modal",ref:t},{content:f(()=>[u("iframe",{class:"form",src:o.onboardingForm},null,8,b)]),_:1},512)],64)}}});const I=p(y,[["__scopeId","data-v-8c8bc27e"]]);export{I as default};
//# sourceMappingURL=Home.87caf225.js.map
