import{M as a}from"./Modal.2a79bddf.js";import{d as r,v as c,r as d,b as _,c as l,e as n,w as i,F as f,a as m,x as u,q as p}from"./registerWidgets.c33434b6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="1a2e0238-532e-4598-914b-0e9c2ce0daa6",e._sentryDebugIdIdentifier="sentry-dbid-1a2e0238-532e-4598-914b-0e9c2ce0daa6")}catch{}})();const b=["src"],y=r({__name:"Home",setup(e){const o=c({onboardingForm:""}),t=d(null);return(g,v)=>{const s=m("router-view");return _(),l(f,null,[n(s,{class:"router"}),n(a,{ref_key:"modal",ref:t},{content:i(()=>[u("iframe",{class:"form",src:o.onboardingForm},null,8,b)]),_:1},512)],64)}}});const I=p(y,[["__scopeId","data-v-8c8bc27e"]]);export{I as default};
//# sourceMappingURL=Home.bc35bf1a.js.map
