import{P as a}from"./Passwordless.42b443a5.js";import{N as r}from"./Navbar.1dd95194.js";import{d as n,b as c,c as p,e as o,G as _,p as i}from"./registerWidgets.4cc86716.js";import{M as m}from"./member.60c494cc.js";import"./CircularLoading.249aa989.js";import"./icons.d4e872e2.js";import"./passwordlessManager.d432fb48.js";import"./logo.084e5d7c.js";import"./asyncComputed.f9d446a7.js";import"./gateway.6112d0c1.js";import"./activeRecord.57c6bf02.js";const d={class:"login"},l=n({__name:"Login",setup(u){const e=_();async function s(t){await m.login(),e.push({name:"home"})}return(t,f)=>(c(),p("div",d,[o(r,{class:"nav"}),o(a,{class:"passwordless",onDone:s})]))}});const B=i(l,[["__scopeId","data-v-c9b2b4e6"]]);export{B as default};
//# sourceMappingURL=Login.6923ff32.js.map
