import{q as t,b as s,c as a}from"./registerWidgets.05268d5e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="a1b955d2-5033-4a64-8fca-7f1f4249e21d",e._sentryDebugIdIdentifier="sentry-dbid-a1b955d2-5033-4a64-8fca-7f1f4249e21d")}catch{}})();const o={},r={class:"organization-settings"};function d(e,n){return s(),a("div",r,"Organization settings")}const c=t(o,[["render",d]]);export{c as default};
//# sourceMappingURL=OrganizationSettings.833dda2b.js.map
