import{d as n,K as l,b as p,t as c,z as a,J as u}from"./registerWidgets.81004098.js";import{a as d}from"./asyncComputed.841de1fc.js";import"./passwordlessManager.d8088db9.js";import{M as b}from"./member.cdefe71a.js";import{C as f}from"./CrudView.20b9da12.js";import"./utils.ac5c1175.js";import"./pubsub.a0411919.js";import"./DropdownMenu.f9c0b8cd.js";import"./CircularLoading.cef8a22f.js";import"./Modal.bc20d9b5.js";const h=n({__name:"Members",setup(_){const r=u().params.organizationId,{loading:s,result:m}=d(()=>b.list(r)),i=l(()=>{var e,t;return{columns:[{name:"Email"},{name:"Role"}],rows:(t=(e=m.value)==null?void 0:e.map(o=>({key:o.email,cells:[{text:o.email,classes:["title","centered"]},{text:o.role,classes:["centered"]}]})))!=null?t:[]}});return(e,t)=>(p(),c(f,{"entity-name":"members",loading:a(s),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:a(i)},null,8,["loading","table"]))}});export{h as default};
//# sourceMappingURL=Members.a254ead0.js.map
