import{x as s}from"./icons.79ac4c38.js";import{d as r,a as c,b as i,c as d,e as _,z as l,S as f,q as b}from"./registerWidgets.dc0b6768.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ebc3e5fb-5a65-4b7a-8e2e-2f024d7a9b8a",e._sentryDebugIdIdentifier="sentry-dbid-ebc3e5fb-5a65-4b7a-8e2e-2f024d7a9b8a")}catch{}})();const u=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(a,n)=>{const o=c("icon");return i(),d("button",{class:"back-btn",onClick:n[0]||(n[0]=p=>t("exitFullscreenPreview"))},[_(o,{class:"icon",path:l(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),f(" Editor ")])}}});const w=b(u,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.780c3f1c.js.map
