import{_ as y}from"./logo.084e5d7c.js";import{q as i,b as s,c as o,O as u,Q as p,x as t,d as m,H as x,a as $,z as a,N as g,e as n,w as v,S as h,F as L,L as N,D as I,al as B}from"./registerWidgets.69eb7b40.js";import{p as l}from"./passwordlessManager.3c745f80.js";import{a as C}from"./asyncComputed.5c8fd07f.js";const S={},b=e=>(u("data-v-462c26c1"),e=e(),p(),e),w={class:"logo"},V=b(()=>t("img",{class:"logo-img",src:y,alt:"Abstra cloud logo"},null,-1)),A=b(()=>t("span",null," Abstra ",-1)),D=[V,A];function F(e,_){return s(),o("div",w,D)}const R=i(S,[["render",F],["__scopeId","data-v-462c26c1"]]),U={key:0},q={key:1,class:"logged"},z={class:"author-email"},E={key:2},H=m({__name:"LoginBlock",setup(e){const _=x(),{result:r,loading:c,refetch:d}=C(async()=>l.getUser());function f(){l.removeUser(),d(),_.push({name:"login"})}return(P,W)=>{const k=$("router-link");return a(c)?(s(),o("div",U,"loading...")):a(r)?(s(),o("div",q,[t("span",z,g(a(r).claims.email),1),t("button",{class:"btn",onClick:f},"Logout")])):(s(),o("div",E,[n(k,{class:"btn",to:"/login"},{default:v(()=>[h("Login")]),_:1})]))}}});const M=i(H,[["__scopeId","data-v-ec693579"]]),O=e=>(u("data-v-069c3c25"),e=e(),p(),e),Q={class:"nav"},T={class:"left"},j={key:0,class:"breadcrumb-container"},G=O(()=>t("span",{class:"divider"},"/",-1)),J={class:"right"},K=m({__name:"Navbar",props:{breadcrumb:null},setup(e){return(_,r)=>(s(),o("nav",Q,[t("div",T,[n(R),e.breadcrumb?(s(),o("div",j,[(s(!0),o(L,null,N(e.breadcrumb,(c,d)=>(s(),o("span",{key:d,class:"breadcrumb-item"},[n(a(B),{class:"breadcrumb-link",to:c.path},{default:v(()=>[h(g(c.label),1)]),_:2},1032,["to"]),G]))),128))])):I("",!0)]),t("div",J,[n(M)])]))}});const se=i(K,[["__scopeId","data-v-069c3c25"]]);export{se as N};
//# sourceMappingURL=Navbar.7e9e7647.js.map
