import{P as r}from"./Passwordless.fb1a0be0.js";import{N as a}from"./Navbar.b8558487.js";import{d as i,b as c,c as d,e as t,H as _,q as p}from"./registerWidgets.ef15081f.js";import{M as f}from"./member.0643a47e.js";import"./CircularLoading.65cb8c64.js";import"./lottie.b93b14fe.js";import"./icons.0b88355c.js";import"./passwordlessManager.b4322d52.js";import"./logo.084e5d7c.js";import"./asyncComputed.86367e33.js";import"./gateway.fa951f3a.js";import"./activeRecord.8aa582bd.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="4fb1a403-6c1e-453f-a62c-4e308b419564",e._sentryDebugIdIdentifier="sentry-dbid-4fb1a403-6c1e-453f-a62c-4e308b419564")}catch{}})();const m={class:"login"},l=i({__name:"Login",setup(e){const o=_();async function s(n){await f.login(),o.push({name:"home"})}return(n,u)=>(c(),d("div",m,[t(a,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const N=p(l,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.323a2d34.js.map
