import{q as n,b as o,c,x as d,d as r,a as _,t as i,w as l,e as u,S as f}from"./registerWidgets.ef15081f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="be829d9d-1308-45d3-a3da-613779f8957e",e._sentryDebugIdIdentifier="sentry-dbid-be829d9d-1308-45d3-a3da-613779f8957e")}catch{}})();const p={},w={width:"12",height:"10",viewBox:"0 0 12 10",fill:"none",xmlns:"http://www.w3.org/2000/svg"},k=d("path",{d:"M2.8725 4.25L5.5575 1.5575L4.5 0.5L0 5L4.5 9.5L5.5575 8.4425L2.8725 5.75H12V4.25H2.8725Z",fill:"#6D7C93"},null,-1),B=[k];function h(e,t){return o(),c("svg",w,B)}const b=n(p,[["render",h]]),g=r({__name:"BackButton",props:{link:null},setup(e){return(t,s)=>{const a=_("router-link");return o(),i(a,{class:"link-button",to:e.link},{default:l(()=>[u(b),f(" Back ")]),_:1},8,["to"])}}});const m=n(g,[["__scopeId","data-v-56a12edc"]]);export{m as B};
//# sourceMappingURL=BackButton.00f354de.js.map
