import{q as r,a,b as i,t as c,f as d,g as p,_,h as u,k as f,T as l,P as h,C as b,M as g,s as y,i as m,j as s,l as w,m as v,n as k}from"./registerWidgets.726232df.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="45fb3e4d-ffce-489d-89aa-ca3bf6c5b103",e._sentryDebugIdIdentifier="sentry-dbid-45fb3e4d-ffce-489d-89aa-ca3bf6c5b103")}catch{}})();const I={};function x(e,t){const o=a("router-view");return i(),c(o,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=r(I,[["render",x]]),n=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.2eef5603.js"),["assets/Player.2eef5603.js","assets/index.bbe106e1.js","assets/registerWidgets.726232df.js","assets/registerWidgets.448db7e9.css","assets/log.bef1eaa6.js","assets/broker.89bb4800.js","assets/passwordlessManager.3b0f9bd3.js","assets/icons.f7969917.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.7cbe573f.js","assets/Passwordless.72b053f6.js","assets/CircularLoading.4a9d4906.js","assets/lottie.1c3b7cde.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/executeJs.209fa4e7.js","assets/PlayerNavbar.1086bae4.js","assets/PlayerNavbar.1542e7ca.css","assets/WidgetsFrame.76941521.js","assets/colors.ad792a0e.js","assets/WidgetsFrame.701a818b.css","assets/Modal.bd7677ba.js","assets/Modal.5aaf8eba.css","assets/executeJs.b0d1ede9.css","assets/broker.f87ad36d.css","assets/DashPlayer.170f6ab0.js","assets/runnerData.99da771c.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.638ec138.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=u({render:()=>f(A)});l.init(),e.use(n),e.use(h),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",g),e.component("Message",y),m(e,n),s(e,w),s(e,v),s(e,k)};D();
//# sourceMappingURL=player.bcacf6eb.js.map
