[data-v-334134e4]:root{--main-font-family: DM Sans, sans-serif}[data-v-334134e4]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #2479df}.subdomain-editor .title[data-v-334134e4]{display:flex;flex-direction:row;align-items:center;gap:10px;font-size:16px;font-weight:700;line-height:18px;letter-spacing:0em;color:#414a58}.subdomain-editor .subtitle[data-v-334134e4]{font-size:14px;font-weight:400;line-height:18px;letter-spacing:0em;color:#414a58}.subdomain-presenter[data-v-334134e4]{margin-top:20px;padding:30px 35px;display:flex;flex-direction:column;gap:30px;background-color:#fff;border-radius:8px}.subdomain-presenter button[data-v-334134e4]{cursor:pointer;display:flex;flex-direction:row;justify-content:center;align-items:center;padding:8px 20px;gap:10px;border:none;border-radius:4px;font-family:DM Sans,sans-serif;background:#2479df;color:#fff;box-shadow:0 2px 4px #00000026;align-self:start}.subdomain-presenter button[data-v-334134e4]:hover{background:#448add;box-shadow:0 4px 12px #00000026}.subdomain-presenter button[data-v-334134e4]:active,.subdomain-presenter button active[data-v-334134e4]{background:#448add;box-shadow:inset 0 4px 4px #0000000f}.link-item[data-v-334134e4]{display:flex;flex-direction:column;gap:10px}.link-item .link-title[data-v-334134e4]{font-size:14px;font-weight:500;line-height:16px;letter-spacing:0em;color:#5a677a}.link-item .link[data-v-334134e4]{font-size:16px;font-weight:500;line-height:21px;letter-spacing:0em;color:#343b46}.link-item .link .custom-subdomain[data-v-334134e4]{color:#3d79d8}.subdomain-change-warning[data-v-334134e4]{display:flex;flex-direction:column;gap:10px;padding:20px 30px;margin-top:35px;background-color:#fff3f2;color:#414a58}.subdomain-change-warning .section-title[data-v-334134e4]{display:flex;flex-direction:row;align-items:center;gap:6px;font-size:14px;font-weight:700;line-height:15px;letter-spacing:0em}.subdomain-change-warning .section-body[data-v-334134e4]{font-weight:400;font-size:13px;line-height:17px}.input-section[data-v-334134e4]{padding:0 30px;display:flex;flex-direction:column}.input-section .error[data-v-334134e4]{display:flex;flex-direction:row;align-items:center;margin-top:12px;gap:6px;font-size:12px;font-weight:500;line-height:13px;letter-spacing:0em;color:#414a58}.subdomain-value-input[data-v-334134e4]{display:flex;flex-direction:row;align-items:center;gap:12px;margin-top:25px;font-size:14px;font-weight:500;line-height:16px;letter-spacing:0em;color:#414a58}.subdomain-value-input input[data-v-334134e4]{border:1px solid #e7e9ed;border-radius:4px;padding:6px 12px}.option-buttons[data-v-334134e4]{display:flex;flex-direction:row;align-items:center;gap:30px;margin-top:30px}.option-buttons .cancel-button[data-v-334134e4]{cursor:pointer;display:flex;flex-direction:row;justify-content:center;align-items:center;padding:8px 20px;gap:10px;border:none;border-radius:4px;font-family:DM Sans,sans-serif;color:#2479df;border:1px solid #2479df;background:transparent}.option-buttons .cancel-button[data-v-334134e4]:hover{background:#f3f8ff}.option-buttons .cancel-button[data-v-334134e4]:active,.option-buttons .cancel-button active[data-v-334134e4]{background:#d6e4f7}.option-buttons .save-button[data-v-334134e4]{cursor:pointer;display:flex;flex-direction:row;justify-content:center;align-items:center;padding:8px 20px;gap:10px;border:none;border-radius:4px;font-family:DM Sans,sans-serif;background:#2479df;color:#fff;box-shadow:0 2px 4px #00000026}.option-buttons .save-button[data-v-334134e4]:hover{background:#448add;box-shadow:0 4px 12px #00000026}.option-buttons .save-button[data-v-334134e4]:active,.option-buttons .save-button active[data-v-334134e4]{background:#448add;box-shadow:inset 0 4px 4px #0000000f}
