import{q as r,a,b as i,t as c,f as p,g as _,_ as d,h as u,k as l,T as f,P as h,C as g,M as y,s as m,i as b,j as s,l as w,m as v,n as k}from"./registerWidgets.5e258592.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="2e014c7c-0cb0-4367-9821-13e916aaef58",e._sentryDebugIdIdentifier="sentry-dbid-2e014c7c-0cb0-4367-9821-13e916aaef58")}catch{}})();const I={};function x(e,t){const o=a("router-view");return i(),c(o,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=r(I,[["render",x]]),n=p({history:_("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>d(()=>import("./Player.a17413da.js"),["assets/Player.a17413da.js","assets/index.fcb40198.js","assets/registerWidgets.5e258592.js","assets/registerWidgets.448db7e9.css","assets/log.c8a96e1b.js","assets/broker.a88b2f01.js","assets/passwordlessManager.0607f999.js","assets/icons.854ecd29.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.3f03b2a5.js","assets/Passwordless.be7c18ca.js","assets/CircularLoading.5475c2b5.js","assets/lottie.8d9ff8b2.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/executeJs.b70f04a2.js","assets/PlayerNavbar.b87f3634.js","assets/PlayerNavbar.b27e2024.css","assets/WidgetsFrame.c1d5ea44.js","assets/colors.3cd7bb26.js","assets/WidgetsFrame.701a818b.css","assets/Modal.8489c194.js","assets/Modal.5aaf8eba.css","assets/executeJs.b0d1ede9.css","assets/broker.f87ad36d.css","assets/DashPlayer.1a3c5072.js","assets/runnerData.ab08ffbd.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.2269e9b0.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=u({render:()=>l(A)});f.init(),e.use(n),e.use(h),e.mount("#app"),e.component("VSelect",g),e.component("Markdown",y),e.component("Message",m),b(e,n),s(e,w),s(e,v),s(e,k)};D();
//# sourceMappingURL=player.b7772f10.js.map
