import{P as r}from"./Passwordless.be7b0055.js";import{N as d}from"./Navbar.46fbd38e.js";import{d as a,b as i,c,e as t,H as _,q as p}from"./registerWidgets.2bf05ebf.js";import{M as m}from"./member.de81de15.js";import"./CircularLoading.241c7a75.js";import"./lottie.314baab9.js";import"./icons.2362754f.js";import"./passwordlessManager.08604e70.js";import"./logo.084e5d7c.js";import"./asyncComputed.62d26af7.js";import"./gateway.61c8f3b2.js";import"./activeRecord.ffd94d66.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="e2f9d5d9-052d-4691-9d91-e27b43155bb0",e._sentryDebugIdIdentifier="sentry-dbid-e2f9d5d9-052d-4691-9d91-e27b43155bb0")}catch{}})();const f={class:"login"},b=a({__name:"Login",setup(e){const o=_();async function s(n){await m.login(),o.push({name:"home"})}return(n,l)=>(i(),c("div",f,[t(d,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const N=p(b,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.2e04cb89.js.map
