import{r,K as d,R as v}from"./registerWidgets.9f96e537.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="645828c6-308c-4f01-ae70-2a3687267760",e._sentryDebugIdIdentifier="sentry-dbid-645828c6-308c-4f01-ae70-2a3687267760")}catch{}})();const y=e=>{const t=r(Date.now()),a=r(!0),l=r(null),u=r(null),o=d(()=>(t.value,e())),s=n=>{l.value=n,u.value=null,a.value=!1},c=n=>{u.value=n,l.value=null,a.value=!1},f=()=>{t.value=Date.now()};return v(()=>o.value,()=>{l.value=null,a.value=!0,o.value.then(s).catch(n=>{console.error(n),c(n)})}),o.value.then(s),{result:l,loading:a,error:u,refetch:f}};export{y as a};
//# sourceMappingURL=asyncComputed.0a45b9d8.js.map
