import{q as r,a,b as i,t as c,f as p,g as _,_ as d,h as u,k as f,T as l,P as h,C as g,M as y,s as m,i as w,j as s,l as b,m as v,n as k}from"./registerWidgets.c33434b6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ea4fc73f-3597-42cf-9752-658138e3aefa",e._sentryDebugIdIdentifier="sentry-dbid-ea4fc73f-3597-42cf-9752-658138e3aefa")}catch{}})();const I={};function x(e,t){const o=a("router-view");return i(),c(o,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=r(I,[["render",x]]),n=p({history:_("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>d(()=>import("./Player.c0c3fd88.js"),["assets/Player.c0c3fd88.js","assets/index.38cbfd6b.js","assets/registerWidgets.c33434b6.js","assets/registerWidgets.a7e6ab4f.css","assets/log.860f5005.js","assets/broker.106cda05.js","assets/passwordlessManager.dde65e6d.js","assets/icons.da9eecb0.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.70b74aa7.js","assets/Passwordless.9bcddd63.js","assets/CircularLoading.8d9a0f4b.js","assets/lottie.02d4abc1.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/executeJs.3b399b39.js","assets/PlayerNavbar.46c0cad7.js","assets/PlayerNavbar.1542e7ca.css","assets/WidgetsFrame.265316d0.js","assets/colors.9e20e4ba.js","assets/WidgetsFrame.701a818b.css","assets/Modal.2a79bddf.js","assets/Modal.5aaf8eba.css","assets/executeJs.b0d1ede9.css","assets/broker.f87ad36d.css","assets/DashPlayer.139d62ed.js","assets/runnerData.68fe0ab2.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.2a2efb36.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=u({render:()=>f(A)});l.init(),e.use(n),e.use(h),e.mount("#app"),e.component("VSelect",g),e.component("Markdown",y),e.component("Message",m),w(e,n),s(e,b),s(e,v),s(e,k)};D();
//# sourceMappingURL=player.48df3a3f.js.map
