import{q as r,a,b as i,t as c,f as d,g as p,_,h as u,k as f,T as l,P as h,C as b,M as g,s as y,i as m,j as s,l as w,m as v,n as k}from"./registerWidgets.db466a36.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="16505d7b-89db-4aab-9007-cc3ecf4f3f79",e._sentryDebugIdIdentifier="sentry-dbid-16505d7b-89db-4aab-9007-cc3ecf4f3f79")}catch{}})();const I={};function x(e,t){const o=a("router-view");return i(),c(o,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=r(I,[["render",x]]),n=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.c55271c4.js"),["assets/Player.c55271c4.js","assets/index.225e18e9.js","assets/registerWidgets.db466a36.js","assets/registerWidgets.448db7e9.css","assets/log.55f57274.js","assets/broker.f37c2e68.js","assets/passwordlessManager.3137a6b4.js","assets/icons.1210223a.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.3c018778.js","assets/Passwordless.2fd90347.js","assets/CircularLoading.57cd4b94.js","assets/lottie.e796547d.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/executeJs.899326bf.js","assets/PlayerNavbar.b1c47987.js","assets/PlayerNavbar.b27e2024.css","assets/WidgetsFrame.5fda7209.js","assets/colors.9a2cbb67.js","assets/WidgetsFrame.701a818b.css","assets/Modal.94856ed8.js","assets/Modal.5aaf8eba.css","assets/executeJs.b0d1ede9.css","assets/broker.f87ad36d.css","assets/DashPlayer.35715721.js","assets/runnerData.70fc6c3f.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.9891ab9c.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=u({render:()=>f(A)});l.init(),e.use(n),e.use(h),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",g),e.component("Message",y),m(e,n),s(e,w),s(e,v),s(e,k)};D();
//# sourceMappingURL=player.14515a18.js.map
