import{x as a}from"./icons.1210223a.js";import{d as c,a as r,b as i,c as d,e as _,z as f,S as l,q as u}from"./registerWidgets.db466a36.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="85d03383-637c-4f03-96b0-3ce3e518f2f1",e._sentryDebugIdIdentifier="sentry-dbid-85d03383-637c-4f03-96b0-3ce3e518f2f1")}catch{}})();const p=c({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const s=r("icon");return i(),d("button",{class:"back-btn",onClick:n[0]||(n[0]=b=>t("exitFullscreenPreview"))},[_(s,{class:"icon",path:f(a),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),l(" Editor ")])}}});const w=u(p,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.dbd919f2.js.map
