import{L as o}from"./lottie.576b6dda.js";import{d as t,r,o as d,b as s,c,x as i,B as f,q as _}from"./registerWidgets.39370cce.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="92ffcc8a-fa8c-43b7-9dfa-34cdc62ba005",n._sentryDebugIdIdentifier="sentry-dbid-92ffcc8a-fa8c-43b7-9dfa-34cdc62ba005")}catch{}})();const l={class:"container"},u=t({__name:"LoadingIndicator",setup(n){const e=r(null);return d(()=>{!e.value||o.loadAnimation({container:e.value,renderer:"svg",loop:!0,autoplay:!0,path:"/circularLoading.json"})}),(a,p)=>(s(),c("div",l,[i("div",{ref_key:"animation",ref:e,class:"animation"},null,512),f(a.$slots,"default",{},void 0,!0)]))}});const g=_(u,[["__scopeId","data-v-c30401d8"]]);export{g as L};
//# sourceMappingURL=LoadingIndicator.1972d60c.js.map
