import{P as r}from"./Passwordless.3318ed89.js";import{N as a}from"./Navbar.6ee659b8.js";import{d,b as c,c as i,e as t,H as _,q as p}from"./registerWidgets.39370cce.js";import{M as m}from"./member.8607fac6.js";import"./CircularLoading.858c95df.js";import"./lottie.576b6dda.js";import"./icons.c1d7cae2.js";import"./passwordlessManager.6cd57365.js";import"./logo.084e5d7c.js";import"./asyncComputed.588e6ddd.js";import"./gateway.96737752.js";import"./activeRecord.fab7288a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="be24aa14-ade6-4d36-b1f5-4dc7cd180c88",e._sentryDebugIdIdentifier="sentry-dbid-be24aa14-ade6-4d36-b1f5-4dc7cd180c88")}catch{}})();const f={class:"login"},l=d({__name:"Login",setup(e){const o=_();async function s(n){await m.login(),o.push({name:"home"})}return(n,u)=>(c(),i("div",f,[t(a,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const N=p(l,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.530965ee.js.map
