import{r,K as f,R as b}from"./registerWidgets.68572380.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="11172ceb-bfa4-4d3f-93ab-71bb19d71c10",e._sentryDebugIdIdentifier="sentry-dbid-11172ceb-bfa4-4d3f-93ab-71bb19d71c10")}catch{}})();const i=e=>{const t=r(Date.now()),a=r(!0),l=r(null),u=r(null),o=f(()=>(t.value,e())),s=n=>{l.value=n,u.value=null,a.value=!1},c=n=>{u.value=n,l.value=null,a.value=!1},d=()=>{t.value=Date.now()};return b(()=>o.value,()=>{l.value=null,a.value=!0,o.value.then(s).catch(n=>{console.error(n),c(n)})}),o.value.then(s),{result:l,loading:a,error:u,refetch:d}};export{i as a};
//# sourceMappingURL=asyncComputed.896b7bde.js.map
