import{P as a}from"./Passwordless.72b053f6.js";import{N as r}from"./Navbar.3c591950.js";import{d,b as i,c,e as t,H as _,q as p}from"./registerWidgets.726232df.js";import{M as m}from"./member.aa350b17.js";import"./CircularLoading.4a9d4906.js";import"./lottie.1c3b7cde.js";import"./icons.f7969917.js";import"./passwordlessManager.3b0f9bd3.js";import"./logo.084e5d7c.js";import"./asyncComputed.638ec138.js";import"./gateway.459f2c9d.js";import"./activeRecord.acbdb8bc.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="707ea044-a5d4-4f74-adc2-8466948a8eb8",e._sentryDebugIdIdentifier="sentry-dbid-707ea044-a5d4-4f74-adc2-8466948a8eb8")}catch{}})();const f={class:"login"},l=d({__name:"Login",setup(e){const o=_();async function s(n){await m.login(),o.push({name:"home"})}return(n,u)=>(i(),c("div",f,[t(r,{class:"nav"}),t(a,{class:"passwordless",onDone:s})]))}});const N=p(l,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.52ebe46a.js.map
