import{d as p,y as _,v,b as r,c,x as i,z as b,A as o,B as u,D as m,E as S,G as g,q as k}from"./registerWidgets.1590c05e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="aaca1061-de3e-4f72-9927-ee592e63b012",e._sentryDebugIdIdentifier="sentry-dbid-aaca1061-de3e-4f72-9927-ee592e63b012")}catch{}})();const h=p({__name:"Modal",props:{containerStyle:null,headerStyle:null,contentStyle:null},emits:["open","close"],setup(e,{expose:s,emit:t}){const y=_(),f=()=>{n.isOpened=!0,t("open")},a=()=>{n.isOpened=!1,t("close")};s({open:f,close:a});const n=v({isOpened:!1});return(l,d)=>(r(),c("div",{class:g(["background",n.isOpened&&"visible"]),onClick:a},[i("div",{class:"container",style:o(e.containerStyle),onClick:d[0]||(d[0]=S(()=>{},["stop"]))},[b(y).header?(r(),c("div",{key:0,class:"header",style:o(e.headerStyle)},[u(l.$slots,"header",{},void 0,!0)],4)):m("",!0),i("div",{class:"content",style:o(e.contentStyle)},[u(l.$slots,"content",{},void 0,!0)],4)],4)],2))}});const I=k(h,[["__scopeId","data-v-24f739ca"]]);export{I as M};
//# sourceMappingURL=Modal.654099b6.js.map
