import{q as r,a,b as i,t as c,f as p,g as _,_ as d,h as u,k as b,T as f,P as l,C as h,M as g,s as y,i as m,j as s,l as w,m as v,n as k}from"./registerWidgets.e8bf9be7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="2ff232a2-58e2-424b-872e-bb6e7bcfb82b",e._sentryDebugIdIdentifier="sentry-dbid-2ff232a2-58e2-424b-872e-bb6e7bcfb82b")}catch{}})();const I={};function x(e,t){const o=a("router-view");return i(),c(o,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=r(I,[["render",x]]),n=p({history:_("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>d(()=>import("./Player.7fea3840.js"),["assets/Player.7fea3840.js","assets/index.51af7d9d.js","assets/registerWidgets.e8bf9be7.js","assets/registerWidgets.448db7e9.css","assets/log.c23fbc0d.js","assets/broker.91d8b3eb.js","assets/passwordlessManager.22684bfc.js","assets/icons.d2d6a2d6.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.3f298a1f.js","assets/Passwordless.2932362a.js","assets/CircularLoading.a096735f.js","assets/lottie.b4c9148a.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/executeJs.50543402.js","assets/PlayerNavbar.79973c72.js","assets/PlayerNavbar.1542e7ca.css","assets/WidgetsFrame.2af7c238.js","assets/colors.73d0e71d.js","assets/WidgetsFrame.701a818b.css","assets/Modal.eeedb03e.js","assets/Modal.5aaf8eba.css","assets/executeJs.b0d1ede9.css","assets/broker.f87ad36d.css","assets/DashPlayer.0919ecc3.js","assets/runnerData.160b1b07.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.15c1fcc9.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=u({render:()=>b(A)});f.init(),e.use(n),e.use(l),e.mount("#app"),e.component("VSelect",h),e.component("Markdown",g),e.component("Message",y),m(e,n),s(e,w),s(e,v),s(e,k)};D();
//# sourceMappingURL=player.608f7304.js.map
