import{q as t,b as s,c as o}from"./registerWidgets.fce18b61.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="0f96b44f-b186-475c-b818-9410ba088fa0",e._sentryDebugIdIdentifier="sentry-dbid-0f96b44f-b186-475c-b818-9410ba088fa0")}catch{}})();const r={},a={class:"organization-settings"};function i(e,n){return s(),o("div",a,"Organization settings")}const d=t(r,[["render",i]]);export{d as default};
//# sourceMappingURL=OrganizationSettings.3b037e7c.js.map
