import{P as a}from"./Passwordless.bf59d50c.js";import{N as r}from"./Navbar.acc7af5b.js";import{d as n,b as c,c as _,e as o,H as i,q as p}from"./registerWidgets.4a0d8d45.js";import{M as m}from"./member.95b1dd50.js";import"./CircularLoading.0d3d2390.js";import"./icons.778999cd.js";import"./passwordlessManager.60e6c76f.js";import"./logo.084e5d7c.js";import"./asyncComputed.52d81103.js";import"./gateway.f0c4d148.js";import"./activeRecord.57c6bf02.js";const d={class:"login"},l=n({__name:"Login",setup(u){const e=i();async function s(t){await m.login(),e.push({name:"home"})}return(t,f)=>(c(),_("div",d,[o(r,{class:"nav"}),o(a,{class:"passwordless",onDone:s})]))}});const B=p(l,[["__scopeId","data-v-c9b2b4e6"]]);export{B as default};
//# sourceMappingURL=Login.98cf7ce9.js.map
