import{q as r,a,b as i,t as c,f as d,g as p,_,h as u,k as b,T as l,P as h,C as f,M as g,s as y,i as m,j as s,l as w,m as v,n as k}from"./registerWidgets.1590c05e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e8b0ac4e-cbed-4eb6-8823-090391c2beb5",e._sentryDebugIdIdentifier="sentry-dbid-e8b0ac4e-cbed-4eb6-8823-090391c2beb5")}catch{}})();const I={};function x(e,t){const o=a("router-view");return i(),c(o,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=r(I,[["render",x]]),n=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.22d9ef1b.js"),["assets/Player.22d9ef1b.js","assets/index.ec584c90.js","assets/registerWidgets.1590c05e.js","assets/registerWidgets.448db7e9.css","assets/log.ab0a8102.js","assets/broker.ac8902bc.js","assets/passwordlessManager.e40e91a8.js","assets/icons.8b9604eb.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.ad5baaef.js","assets/Passwordless.f9a4a30d.js","assets/CircularLoading.30b3ab43.js","assets/lottie.1e0c432a.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/executeJs.22dd091f.js","assets/PlayerNavbar.d43f7d66.js","assets/PlayerNavbar.b27e2024.css","assets/WidgetsFrame.122943b5.js","assets/colors.4ff9f650.js","assets/WidgetsFrame.701a818b.css","assets/Modal.654099b6.js","assets/Modal.5aaf8eba.css","assets/executeJs.b0d1ede9.css","assets/broker.f87ad36d.css","assets/DashPlayer.2e9838f9.js","assets/runnerData.a4823d6a.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.0f7a44c1.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=u({render:()=>b(A)});l.init(),e.use(n),e.use(h),e.mount("#app"),e.component("VSelect",f),e.component("Markdown",g),e.component("Message",y),m(e,n),s(e,w),s(e,v),s(e,k)};D();
//# sourceMappingURL=player.b3bdeeae.js.map
