import{d as v,K as D,b as u,c as g,z as t,t as d,D as c,F as w,J as b,H as k,q as I}from"./registerWidgets.c33434b6.js";import{D as P,n as q}from"./DashPlayer.139d62ed.js";import{L as x}from"./CircularLoading.8d9a0f4b.js";import{r as B}from"./index.38cbfd6b.js";import{B as R}from"./BackButton.f4e929e5.js";import{a as l}from"./asyncComputed.2a2efb36.js";import{D as C}from"./dashes.5de69797.js";import{W as F}from"./workspaces.ea8984dc.js";import"./passwordlessManager.dde65e6d.js";import"./runnerData.68fe0ab2.js";import"./executeJs.3b399b39.js";import"./PlayerNavbar.46c0cad7.js";import"./icons.da9eecb0.js";import"./WidgetsFrame.265316d0.js";import"./colors.9e20e4ba.js";import"./Modal.2a79bddf.js";import"./log.860f5005.js";import"./Passwordless.9bcddd63.js";import"./lottie.02d4abc1.js";import"./activeRecord.cbf414d4.js";(function(){try{var s=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(s._sentryDebugIds=s._sentryDebugIds||{},s._sentryDebugIds[a]="8b162e25-657c-4af6-8ef2-263ab4689ce2",s._sentryDebugIdIdentifier="sentry-dbid-8b162e25-657c-4af6-8ef2-263ab4689ce2")}catch{}})();const E=v({__name:"DashPreview",setup(s){const a=b(),o=k(),m=({id:e,type:n})=>{n==="dash"?(o.push({name:"dashPreview",params:{dashId:e},query:a.query}),h()):o.push({name:"form-preview",params:{formId:e},query:a.query})},f=()=>{var e;!((e=r.value)!=null&&e.path)||o.push(`/_editor/dash/${encodeURIComponent(r.value.path)}`)},{loading:y,result:r,refetch:h}=l(()=>C.get(a.params.dashPath)),{result:i}=l(()=>F.get()),p=D(()=>{if(!r.value||!i.value||!r.value.makeRunnerData(i.value))return null;const e=q.create(r.value.makeRunnerData(i.value),!1);return e.onRedirect(({url:n,queryParams:_})=>B(o,n,_)),e});return(e,n)=>(u(),g(w,null,[t(y)||!t(r)?(u(),d(x,{key:0,class:"loading",justify:"center"})):c("",!0),t(p)?(u(),d(P,{key:1,class:"player",dash:t(p).runnerData,"is-preview":!0,params:t(a).query,"dash-player-state":t(p),onNavigate:m},null,8,["dash","params","dash-player-state"])):c("",!0),t(r)?(u(),d(R,{key:2,onExitFullscreenPreview:f})):c("",!0)],64))}});const Z=I(E,[["__scopeId","data-v-dde58483"]]);export{Z as default};
//# sourceMappingURL=DashPreview.a11548b7.js.map
