import{q as r,a,b as i,t as d,f as c,g as p,_,h as u,k as f,T as l,P as h,C as b,M as g,s as y,i as m,j as s,l as w,m as v,n as k}from"./registerWidgets.6f0bbac2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="391d3829-aaf5-4530-9bb6-0f2565706ad2",e._sentryDebugIdIdentifier="sentry-dbid-391d3829-aaf5-4530-9bb6-0f2565706ad2")}catch{}})();const I={};function x(e,t){const o=a("router-view");return i(),d(o,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=r(I,[["render",x]]),n=c({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.7fd096db.js"),["assets/Player.7fd096db.js","assets/index.c2ce3dd4.js","assets/registerWidgets.6f0bbac2.js","assets/registerWidgets.448db7e9.css","assets/log.e20e536c.js","assets/broker.2e71ffda.js","assets/passwordlessManager.643e43e8.js","assets/icons.33d01da0.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.1ce994cb.js","assets/Passwordless.8d7065c4.js","assets/CircularLoading.64e0c9cf.js","assets/lottie.68b1efe0.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/executeJs.5ccd414f.js","assets/PlayerNavbar.e622520f.js","assets/PlayerNavbar.b27e2024.css","assets/WidgetsFrame.da1e36e0.js","assets/colors.44698f96.js","assets/WidgetsFrame.701a818b.css","assets/Modal.4278a303.js","assets/Modal.5aaf8eba.css","assets/executeJs.b0d1ede9.css","assets/broker.f87ad36d.css","assets/DashPlayer.b15f40cf.js","assets/runnerData.48e4b7b9.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.e83909df.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=u({render:()=>f(A)});l.init(),e.use(n),e.use(h),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",g),e.component("Message",y),m(e,n),s(e,w),s(e,v),s(e,k)};D();
//# sourceMappingURL=player.bfe4fe49.js.map
