import{r as a,K as d,R as v}from"./registerWidgets.0897334f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="4c387cd8-a8f3-410c-8c47-7b2064e56fb1",e._sentryDebugIdIdentifier="sentry-dbid-4c387cd8-a8f3-410c-8c47-7b2064e56fb1")}catch{}})();const b=e=>{const t=a(Date.now()),l=a(!0),r=a(null),u=a(null),o=d(()=>(t.value,e())),c=n=>{r.value=n,u.value=null,l.value=!1},s=n=>{u.value=n,r.value=null,l.value=!1},f=()=>{t.value=Date.now()};return v(()=>o.value,()=>{r.value=null,l.value=!0,o.value.then(c).catch(n=>{console.error(n),s(n)})}),o.value.then(c),{result:r,loading:l,error:u,refetch:f}};export{b as a};
//# sourceMappingURL=asyncComputed.14546baa.js.map
