import{q as t,b as s,c as o}from"./registerWidgets.cbdb5b20.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="cf5a07b9-8541-4c49-8207-1ff32027f822",e._sentryDebugIdIdentifier="sentry-dbid-cf5a07b9-8541-4c49-8207-1ff32027f822")}catch{}})();const r={},f={class:"organization-settings"};function c(e,n){return s(),o("div",f,"Organization settings")}const d=t(r,[["render",c]]);export{d as default};
//# sourceMappingURL=OrganizationSettings.d4230b9b.js.map
