import{u as r}from"./icons.e22fc21e.js";import{d as u,J as d,H as i,a as p,b as _,c as l,e as f,z as b,S as m,q as y}from"./registerWidgets.966858c5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="19aa9aac-cb6e-47cb-9ae7-5839810a3f92",e._sentryDebugIdIdentifier="sentry-dbid-19aa9aac-cb6e-47cb-9ae7-5839810a3f92")}catch{}})();const v=u({__name:"PreviewButton",props:{model:null},setup(e){const t=e,o=d(),a=i(),s=()=>{const n=o.query;a.push({path:`/_editor/${t.model.routeName}/${encodeURIComponent(t.model.path)}/preview`,query:n})};return(n,w)=>{const c=p("icon");return _(),l("button",{class:"preview-button",onClick:s},[f(c,{class:"icon",path:b(r),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),m(" Preview ")])}}});const I=y(v,[["__scopeId","data-v-4b4c109d"]]);export{I as P};
//# sourceMappingURL=PreviewButton.9c1f69b1.js.map
