import{P as r}from"./Passwordless.451bc665.js";import{N as a}from"./Navbar.a0b72b66.js";import{d as i,b as c,c as d,e as t,H as _,q as p}from"./registerWidgets.dc0b6768.js";import{M as m}from"./member.bbc60acc.js";import"./CircularLoading.8d483ca6.js";import"./lottie.eb38a9e8.js";import"./icons.79ac4c38.js";import"./passwordlessManager.914ef4f9.js";import"./logo.084e5d7c.js";import"./asyncComputed.1ef6bcd7.js";import"./gateway.320dd104.js";import"./activeRecord.81c73286.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="6462e30d-c4e8-48a6-8a85-63e361232ca2",e._sentryDebugIdIdentifier="sentry-dbid-6462e30d-c4e8-48a6-8a85-63e361232ca2")}catch{}})();const l={class:"login"},f=i({__name:"Login",setup(e){const o=_();async function s(n){await m.login(),o.push({name:"home"})}return(n,u)=>(c(),d("div",l,[t(a,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const N=p(f,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.5d2d8178.js.map
