import{d as o,b as d,c,q as a}from"./registerWidgets.68b4d727.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="22e34d2d-efff-41b0-bcd3-64005a53fd08",e._sentryDebugIdIdentifier="sentry-dbid-22e34d2d-efff-41b0-bcd3-64005a53fd08")}catch{}})();const f=["href"],_=o({__name:"DocsButton",props:{path:null},setup(e){return(t,n)=>{var s;return d(),c("a",{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank"}," Docs ",8,f)}}});const u=a(_,[["__scopeId","data-v-9fec5678"]]);export{u as D};
//# sourceMappingURL=DocsButton.f7d961ed.js.map
