import{t as i,p as r}from"./passwordlessManager.643e43e8.js";import"./registerWidgets.6f0bbac2.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="a27ad1f2-2f49-4c87-a965-862e53807f83",t._sentryDebugIdIdentifier="sentry-dbid-a27ad1f2-2f49-4c87-a965-862e53807f83")}catch{}})();const n=i("cloud-api");class p{static async get(e){const a=await(await fetch(`${n}/console/${e}`,{headers:{...r.getUserHeaders("Author-Authorization")}})).text();return a?JSON.parse(a):null}static async post(e,s){const o=await(await fetch(`${n}/console/${e}`,{method:"POST",headers:{"Content-Type":"application/json",...r.getUserHeaders("Author-Authorization")},body:JSON.stringify(s)})).text();return o?JSON.parse(o):null}static async patch(e,s){const o=await(await fetch(`${n}/console/${e}`,{method:"PATCH",headers:{"Content-Type":"application/json",...r.getUserHeaders("Author-Authorization")},body:JSON.stringify(s)})).text();return o?JSON.parse(o):null}static async delete(e){await fetch(`${n}/console/${e}`,{method:"DELETE",headers:{"Content-Type":"application/json",...r.getUserHeaders("Author-Authorization")}})}}export{p as C};
//# sourceMappingURL=gateway.2f3fe23e.js.map
