import{r as u,K as d,R as v}from"./registerWidgets.ef15081f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="6fc15bc9-37f8-4c95-907c-f1ed3fde8dfe",e._sentryDebugIdIdentifier="sentry-dbid-6fc15bc9-37f8-4c95-907c-f1ed3fde8dfe")}catch{}})();const y=e=>{const t=u(Date.now()),l=u(!0),r=u(null),a=u(null),o=d(()=>(t.value,e())),c=n=>{r.value=n,a.value=null,l.value=!1},s=n=>{a.value=n,r.value=null,l.value=!1},f=()=>{t.value=Date.now()};return v(()=>o.value,()=>{r.value=null,l.value=!0,o.value.then(c).catch(n=>{console.error(n),s(n)})}),o.value.then(c),{result:r,loading:l,error:a,refetch:f}};export{y as a};
//# sourceMappingURL=asyncComputed.86367e33.js.map
