import{q as t,b as s,c}from"./registerWidgets.9f96e537.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="f1650943-c3c4-4ff3-bfeb-871dd664c72e",e._sentryDebugIdIdentifier="sentry-dbid-f1650943-c3c4-4ff3-bfeb-871dd664c72e")}catch{}})();const o={},r={class:"organization-settings"};function d(e,n){return s(),c("div",r,"Organization settings")}const a=t(o,[["render",d]]);export{a as default};
//# sourceMappingURL=OrganizationSettings.e650e8ec.js.map
