import{x as a}from"./icons.33d01da0.js";import{d as r,a as c,b as d,c as i,e as _,z as l,S as u,q as f}from"./registerWidgets.6f0bbac2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="245d9d72-2b49-47e8-8b0b-140a75e182cf",e._sentryDebugIdIdentifier="sentry-dbid-245d9d72-2b49-47e8-8b0b-140a75e182cf")}catch{}})();const b=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const s=c("icon");return d(),i("button",{class:"back-btn",onClick:n[0]||(n[0]=p=>t("exitFullscreenPreview"))},[_(s,{class:"icon",path:l(a),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),u(" Editor ")])}}});const w=f(b,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.831b73cf.js.map
