import{x as s}from"./icons.d2d6a2d6.js";import{d as r,a as d,b as c,c as i,e as _,z as l,S as u,q as f}from"./registerWidgets.e8bf9be7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="fdadae7d-7601-4927-a373-143449e2d301",e._sentryDebugIdIdentifier="sentry-dbid-fdadae7d-7601-4927-a373-143449e2d301")}catch{}})();const p=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const a=d("icon");return c(),i("button",{class:"back-btn",onClick:n[0]||(n[0]=b=>t("exitFullscreenPreview"))},[_(a,{class:"icon",path:l(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),u(" Editor ")])}}});const w=f(p,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.0c78961a.js.map
