import{q as o,a as r,b as a,t as n,f as i,g as c,_ as p,h as _,j as h,T as u,P as d,C as l,M as m,s as g,i as t,k as v,l as w,m as f}from"./registerWidgets.bb4c7eff.js";const k={};function y(e,W){const s=r("router-view");return a(),n(s,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const b=o(k,[["render",y]]),x=i({history:c("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>p(()=>import("./Player.2ee12b8a.js"),["assets/Player.2ee12b8a.js","assets/index.82e1a6b3.js","assets/registerWidgets.bb4c7eff.js","assets/registerWidgets.64440b7a.css","assets/log.6e68571d.js","assets/broker.cb081a13.js","assets/passwordlessManager.a806df6a.js","assets/icons.e3de8035.js","assets/Passwordless.dd440ef2.js","assets/CircularLoading.8dab92fc.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.07735323.css","assets/WidgetsFrame.36374261.js","assets/PlayerNavbar.31f81a29.js","assets/PlayerNavbar.89be930f.css","assets/Modal.bf534f7d.js","assets/Modal.5aaf8eba.css","assets/WidgetsFrame.3b037b7b.css","assets/broker.bebc9a1e.css","assets/DashPlayer.b337353d.js","assets/runnerData.e56dab20.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.0adffaf6.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),A=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=_({render:()=>h(b)});u.init(),e.use(x),e.use(d),e.mount("#app"),e.component("VSelect",l),e.component("Markdown",m),e.component("Message",g),t(e,v),t(e,w),t(e,f)};A();
//# sourceMappingURL=player.154a68b3.js.map
