import{q as o,a as r,b as a,t as n,f as i,g as c,_ as p,h as _,j as h,T as u,P as d,C as l,M as m,s as g,i as t,k as v,l as w,m as f}from"./registerWidgets.4a0d8d45.js";const k={};function y(e,W){const s=r("router-view");return a(),n(s,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const b=o(k,[["render",y]]),x=i({history:c("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>p(()=>import("./Player.716b717a.js"),["assets/Player.716b717a.js","assets/index.aeb68571.js","assets/registerWidgets.4a0d8d45.js","assets/registerWidgets.a7e6ab4f.css","assets/log.f9199108.js","assets/broker.c113cf58.js","assets/passwordlessManager.60e6c76f.js","assets/icons.e3de8035.js","assets/Passwordless.c13aa055.js","assets/CircularLoading.0d3d2390.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.07735323.css","assets/WidgetsFrame.171c7126.js","assets/PlayerNavbar.e4922711.js","assets/PlayerNavbar.89be930f.css","assets/Modal.2f62582a.js","assets/Modal.5aaf8eba.css","assets/WidgetsFrame.3b037b7b.css","assets/broker.bebc9a1e.css","assets/DashPlayer.df6fc421.js","assets/runnerData.18839000.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.52d81103.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),A=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=_({render:()=>h(b)});u.init(),e.use(x),e.use(d),e.mount("#app"),e.component("VSelect",l),e.component("Markdown",m),e.component("Message",g),t(e,v),t(e,w),t(e,f)};A();
//# sourceMappingURL=player.8e2b9576.js.map
