.hook-settings[data-v-6e8accf0]{width:960px;max-width:calc(100vw - 40px);padding-top:50px;align-self:center}.dropdown[data-v-cac46a2e]{font-size:.8em;padding:.5em 1em;position:relative;border:1px solid #d4d8de;border-radius:6px;align-self:stretch;color:#8692a5;resize:none;user-select:none;cursor:pointer;background-color:#fff}.dropdown[data-v-cac46a2e]:after{content:"";border:solid #8692a5;border-width:0 3px 3px 0;display:inline-block;padding:3px;position:absolute;right:10px;top:50%;transform:translateY(-50%) rotate(45deg)}.dropdown:focus .options-wrapper[data-v-cac46a2e]{display:unset}.dropdown .options-wrapper[data-v-cac46a2e]{position:absolute;top:calc(100% + 2px);left:0;right:0;background-color:#fff;padding:.5em 0;border-radius:6px;box-shadow:0 0 2px #6d7c93;display:none}.dropdown .options-wrapper .option[data-v-cac46a2e]{cursor:pointer;padding:.15em 1em}.dropdown .options-wrapper .option[data-v-cac46a2e]:hover{background-color:#d4d8de90}[data-v-8956304f]:root{--main-font-family: DM Sans, sans-serif}[data-v-8956304f]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #2479df}.hook-runner[data-v-8956304f]{width:960px;max-width:calc(100vw - 40px);padding-top:50px;align-self:center;display:flex;flex:1;flex-direction:column;color:#6d7c93;gap:10px;overflow:hidden}.hook-runner .title[data-v-8956304f]{display:flex;gap:10px;align-items:center;font-size:20px;font-weight:700;margin-bottom:10px;user-select:none}.hook-runner .execution-button[data-v-8956304f]{cursor:pointer;display:flex;flex-direction:row;justify-content:center;align-items:center;gap:10px;border:none;border-radius:4px;font-family:DM Sans,sans-serif;background-color:#acb5c8;color:#fff;padding:4px 10px;gap:5px}align-items .hook-runner .execution-button[data-v-8956304f]:hover{background-color:#b5c8d3}.hook-runner .execution-button.abort[data-v-8956304f]{background-color:#d35249}.hook-runner .section[data-v-8956304f]{flex-direction:column}.hook-runner .section .section-header[data-v-8956304f]{display:flex;flex-direction:row;align-items:center;gap:10px;margin-top:10px;font-size:16px;text-transform:uppercase;font-weight:700;user-select:none}.hook-runner .section .subsection-label[data-v-8956304f]{font-size:12px;text-transform:uppercase;margin-top:5px;user-select:none;display:flex;flex-direction:row;align-items:center;gap:10px}.hook-runner .section>*[data-v-8956304f]{margin:2.5px 0}.hook-runner input[data-v-8956304f],.hook-runner textarea[data-v-8956304f]{flex:1;font-size:.8em;padding:.5em 1em;border:1px solid #d4d8de;border-radius:6px;align-self:stretch;color:#8692a5}.hook-runner textarea[data-v-8956304f]{width:100%;display:flex;resize:vertical;max-height:300px;min-height:100px;box-sizing:border-box}.hook-runner .no-execution-message[data-v-8956304f]{width:100%;height:60px;text-align:center;background-color:#f3f4f5;display:flex;justify-content:center;align-items:center}.params-input[data-v-8956304f]{display:flex;flex-direction:row;gap:10px;align-items:center}.params-input .delete-icon[data-v-8956304f],.action-icon[data-v-8956304f]{cursor:pointer}.property[data-v-8956304f]{display:flex;flex-direction:row;align-items:center;margin-left:10px;font-size:10px}.property input[data-v-8956304f]{width:10px}[data-v-a25bf527]:root{--main-font-family: DM Sans, sans-serif}[data-v-a25bf527]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #2479df}.page[data-v-a25bf527]{display:flex;flex-direction:column;height:100%}.editor[data-v-a25bf527]{flex-grow:1;min-height:0;max-height:100%;box-sizing:border-box;border:#dbdee4 1px solid}.loading[data-v-a25bf527]{display:flex;justify-content:center;flex-direction:column;align-items:center;height:100%}
