import{q as t,b as s,c as a}from"./registerWidgets.726232df.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="7147e55e-66f5-4823-aafb-3f3a7fd067a9",e._sentryDebugIdIdentifier="sentry-dbid-7147e55e-66f5-4823-aafb-3f3a7fd067a9")}catch{}})();const o={},r={class:"organization-settings"};function f(e,n){return s(),a("div",r,"Organization settings")}const c=t(o,[["render",f]]);export{c as default};
//# sourceMappingURL=OrganizationSettings.cbea5955.js.map
