import{q as r,a,b as i,t as c,f as d,g as p,_,h as u,k as f,T as l,P as h,C as b,M as g,s as y,i as m,j as s,l as v,m as w,n as k}from"./registerWidgets.0e006b6f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="975dc6f7-5046-4473-bff2-ee2384b8090d",e._sentryDebugIdIdentifier="sentry-dbid-975dc6f7-5046-4473-bff2-ee2384b8090d")}catch{}})();const I={};function x(e,t){const n=a("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=r(I,[["render",x]]),o=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.2b6ca518.js"),["assets/Player.2b6ca518.js","assets/index.cad410b6.js","assets/registerWidgets.0e006b6f.js","assets/registerWidgets.448db7e9.css","assets/uuid.9b3680ca.js","assets/broker.a7e23963.js","assets/passwordlessManager.4cf24a2b.js","assets/pubsub.13db2123.js","assets/icons.6bb7a228.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.42c8d93f.js","assets/Passwordless.11ab8892.js","assets/CircularLoading.091208e5.js","assets/lottie.b974d0b6.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.86ac0c56.css","assets/executeJs.64987f61.js","assets/PlayerNavbar.a41a317c.js","assets/PlayerNavbar.adff8b48.css","assets/WidgetsFrame.58e774c2.js","assets/colors.7dccb471.js","assets/WidgetsFrame.701a818b.css","assets/Modal.d54926bb.js","assets/Modal.5aaf8eba.css","assets/executeJs.887e9a58.css","assets/broker.5f3abad8.css","assets/DashPlayer.f125dd11.js","assets/runnerData.dc6d3f24.js","assets/DashPlayer.ef4a798d.css","assets/asyncComputed.62aacf33.js","assets/Player.df829dc6.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{const e=u({render:()=>f(A)});l.init(),e.use(o),e.use(h),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",g),e.component("Message",y),m(e,o),s(e,v),s(e,w),s(e,k)};D();
//# sourceMappingURL=player.a83d94cf.js.map
