import{M as r}from"./Modal.cbda4e16.js";import{d as a,v as c,r as d,b as _,c as f,e as n,w as l,F as i,a as m,x as u,q as b}from"./registerWidgets.966858c5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="e0c58d97-1322-4bfa-812d-9202be40bf34",e._sentryDebugIdIdentifier="sentry-dbid-e0c58d97-1322-4bfa-812d-9202be40bf34")}catch{}})();const p=["src"],y=a({__name:"Home",setup(e){const o=c({onboardingForm:""}),t=d(null);return(g,v)=>{const s=m("router-view");return _(),f(i,null,[n(s,{class:"router"}),n(r,{ref_key:"modal",ref:t},{content:l(()=>[u("iframe",{class:"form",src:o.onboardingForm},null,8,p)]),_:1},512)],64)}}});const I=b(y,[["__scopeId","data-v-8c8bc27e"]]);export{I as default};
//# sourceMappingURL=Home.5a725915.js.map
