import{P as r}from"./Passwordless.11ab8892.js";import{N as a}from"./Navbar.37cfe3a8.js";import{d,b as i,c,e as t,H as p,q as _}from"./registerWidgets.0e006b6f.js";import{M as m}from"./member.7da2b412.js";import"./CircularLoading.091208e5.js";import"./lottie.b974d0b6.js";import"./icons.6bb7a228.js";import"./passwordlessManager.4cf24a2b.js";import"./pubsub.13db2123.js";import"./logo.084e5d7c.js";import"./asyncComputed.62aacf33.js";import"./gateway.68890283.js";import"./activeRecord.d399634f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="20194414-f13d-4d73-888d-4273434c34b6",e._sentryDebugIdIdentifier="sentry-dbid-20194414-f13d-4d73-888d-4273434c34b6")}catch{}})();const f={class:"login"},l=d({__name:"Login",setup(e){const o=p();async function s(n){await m.login(),o.push({name:"home"})}return(n,u)=>(i(),c("div",f,[t(a,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const B=_(l,[["__scopeId","data-v-c9b2b4e6"]]);export{B as default};
//# sourceMappingURL=Login.49fb69e2.js.map
