import{P as r}from"./Passwordless.272e470d.js";import{N as a}from"./Navbar.44f2c4a6.js";import{d as i,b as d,c,e as t,H as _,q as p}from"./registerWidgets.05268d5e.js";import{M as m}from"./member.7e0cab06.js";import"./CircularLoading.b36562a7.js";import"./lottie.ea647b01.js";import"./icons.7c77483f.js";import"./passwordlessManager.61e5b6aa.js";import"./logo.084e5d7c.js";import"./asyncComputed.8f90be18.js";import"./gateway.c44af888.js";import"./activeRecord.bacc466b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="2c489393-517a-47d8-9834-4e86948275e8",e._sentryDebugIdIdentifier="sentry-dbid-2c489393-517a-47d8-9834-4e86948275e8")}catch{}})();const l={class:"login"},f=i({__name:"Login",setup(e){const o=_();async function s(n){await m.login(),o.push({name:"home"})}return(n,u)=>(d(),c("div",l,[t(a,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const N=p(f,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.55d7ed47.js.map
