import{P as r}from"./Passwordless.2932362a.js";import{N as d}from"./Navbar.1ac45df5.js";import{d as a,b as i,c,e as t,H as _,q as p}from"./registerWidgets.e8bf9be7.js";import{M as b}from"./member.b6bf4a71.js";import"./CircularLoading.a096735f.js";import"./lottie.b4c9148a.js";import"./icons.d2d6a2d6.js";import"./passwordlessManager.22684bfc.js";import"./logo.084e5d7c.js";import"./asyncComputed.15c1fcc9.js";import"./gateway.52ae1994.js";import"./activeRecord.66fd8f56.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="d250dec8-5d56-4b79-a4b8-bdf39bb1bcd1",e._sentryDebugIdIdentifier="sentry-dbid-d250dec8-5d56-4b79-a4b8-bdf39bb1bcd1")}catch{}})();const m={class:"login"},f=a({__name:"Login",setup(e){const o=_();async function s(n){await b.login(),o.push({name:"home"})}return(n,l)=>(i(),c("div",m,[t(d,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const N=p(f,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.541f142a.js.map
