import{P as r}from"./Passwordless.2fd90347.js";import{N as d}from"./Navbar.3710a623.js";import{d as a,b as i,c,e as t,H as _,q as p}from"./registerWidgets.db466a36.js";import{M as f}from"./member.2fd7fb33.js";import"./CircularLoading.57cd4b94.js";import"./lottie.e796547d.js";import"./icons.1210223a.js";import"./passwordlessManager.3137a6b4.js";import"./logo.084e5d7c.js";import"./asyncComputed.9891ab9c.js";import"./gateway.6ecad65a.js";import"./activeRecord.74699a56.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="42fd27df-a1eb-401d-9d53-2240e55dd34b",e._sentryDebugIdIdentifier="sentry-dbid-42fd27df-a1eb-401d-9d53-2240e55dd34b")}catch{}})();const m={class:"login"},l=a({__name:"Login",setup(e){const o=_();async function s(n){await f.login(),o.push({name:"home"})}return(n,u)=>(i(),c("div",m,[t(d,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const N=p(l,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.279c979b.js.map
