import{u as r}from"./icons.ef86ff2e.js";import{d,J as u,H as i,a as p,b as _,c as l,e as f,z as b,S as m,q as y}from"./registerWidgets.68b4d727.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="579afe03-4322-46ac-b84d-b3e293cc665a",e._sentryDebugIdIdentifier="sentry-dbid-579afe03-4322-46ac-b84d-b3e293cc665a")}catch{}})();const v=d({__name:"PreviewButton",props:{model:null},setup(e){const t=e,o=u(),s=i(),a=()=>{const n=o.query;s.push({path:`/_editor/${t.model.routeName}/${encodeURIComponent(t.model.path)}/preview`,query:n})};return(n,w)=>{const c=p("icon");return _(),l("button",{class:"preview-button",onClick:a},[f(c,{class:"icon",path:b(r),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),m(" Preview ")])}}});const I=y(v,[["__scopeId","data-v-4b4c109d"]]);export{I as P};
//# sourceMappingURL=PreviewButton.2f36f9e0.js.map
