import{S as d}from"./Sidebar.852d4262.js";import{N as m}from"./Navbar.4071bc21.js";import{F as l,G as p,H as u}from"./icons.4255d62c.js";import{d as _,K as b,b as f,c as g,e as t,z as r,x as v,F as y,J as z,a as w,q as I}from"./registerWidgets.9f96e537.js";import{a as h}from"./asyncComputed.0a45b9d8.js";import"./gateway.052cd6ee.js";import{O}from"./organization.221e9a91.js";import"./Tooltip.612480f5.js";import"./logo.084e5d7c.js";import"./passwordlessManager.5f237f08.js";import"./activeRecord.81c11d03.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="cd37e6c8-20bd-473f-9391-a4a9fd24da77",e._sentryDebugIdIdentifier="sentry-dbid-cd37e6c8-20bd-473f-9391-a4a9fd24da77")}catch{}})();const x={class:"organization"},k=_({__name:"Organization",setup(e){const n=z().params.organizationId,{result:o}=h(()=>O.get(n)),s=b(()=>o.value?[{label:o.value.name,path:`/organizations/${o.value.id}`}]:void 0),i=[{name:"Organization",items:[{name:"Projects",icon:l,path:"projects"},{name:"Members",icon:p,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(B,D)=>{const c=w("router-view");return f(),g(y,null,[t(m,{breadcrumb:r(s)},null,8,["breadcrumb"]),v("div",x,[t(d,{class:"sidebar",sections:r(i)},null,8,["sections"]),t(c)])],64)}}});const J=I(k,[["__scopeId","data-v-7eef90b7"]]);export{J as default};
//# sourceMappingURL=Organization.0fec4368.js.map
