.login[data-v-64286f28]{display:grid;height:100%;grid-template-rows:auto 1fr;justify-items:center}.login .passwordless[data-v-64286f28]{width:640px;max-width:calc(100vw - 40px);align-self:center}.login .passwordless[data-v-64286f28] .auth-info,.login .passwordless[data-v-64286f28] .auth-token{display:flex;flex-direction:column;align-items:stretch;background-color:#fff;padding:100px 20px;box-shadow:0 0 40px #0000001a;border-radius:4px}.login .passwordless[data-v-64286f28] .auth-info .next-button,.login .passwordless[data-v-64286f28] .auth-info .secondary-button,.login .passwordless[data-v-64286f28] .auth-token .next-button,.login .passwordless[data-v-64286f28] .auth-token .secondary-button{background-color:#000;color:#fff;border:none;border-radius:4px;padding:.5rem 1rem;font-size:1rem;font-weight:500;height:60px;cursor:pointer;transition:all .2s ease-in-out}.login .passwordless[data-v-64286f28] .auth-info .next-button:hover,.login .passwordless[data-v-64286f28] .auth-info .secondary-button:hover,.login .passwordless[data-v-64286f28] .auth-token .next-button:hover,.login .passwordless[data-v-64286f28] .auth-token .secondary-button:hover{background:var(--primary-color-dark)}
