import{d as r,r as i,o as l,a3 as u,b as f,c,N as b,ad as y}from"./registerWidgets.fce18b61.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="3d9dde79-2d7f-4d2b-b947-1d4ed7217583",e._sentryDebugIdIdentifier="sentry-dbid-3d9dde79-2d7f-4d2b-b947-1d4ed7217583")}catch{}})();const g=r({__name:"ActionButton",props:{action:null},emits:["next"],setup(e,{emit:n}){const o=e,d=i(null);l(()=>{d.value&&o.action.setElement(d.value),u.addAction(o.action)});const s=()=>n("next");return(m,t)=>(f(),c("button",{ref_key:"element",ref:d,class:"next-button",onClick:t[0]||(t[0]=a=>s()),onKeydown:t[1]||(t[1]=y(a=>s(),["enter"]))},b(e.action.name),545))}});export{g as _};
//# sourceMappingURL=ActionButton.vue_vue_type_script_setup_true_lang.9474c75a.js.map
