import{q as t,b as a,c as s}from"./registerWidgets.ef15081f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="d89ac9d7-936f-424a-a23b-e94afbcf23a6",e._sentryDebugIdIdentifier="sentry-dbid-d89ac9d7-936f-424a-a23b-e94afbcf23a6")}catch{}})();const o={},r={class:"organization-settings"};function d(e,n){return a(),s("div",r,"Organization settings")}const f=t(o,[["render",d]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.acb7d800.js.map
