import{P as r}from"./Passwordless.be7c18ca.js";import{N as a}from"./Navbar.59d68b5d.js";import{d as i,b as c,c as d,e as t,H as _,q as f}from"./registerWidgets.5e258592.js";import{M as p}from"./member.64f66c82.js";import"./CircularLoading.5475c2b5.js";import"./lottie.8d9ff8b2.js";import"./icons.854ecd29.js";import"./passwordlessManager.0607f999.js";import"./logo.084e5d7c.js";import"./asyncComputed.2269e9b0.js";import"./gateway.772dec88.js";import"./activeRecord.b3eba751.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="0b20f4c1-2d0b-4802-87ef-e87cfb8a6f14",e._sentryDebugIdIdentifier="sentry-dbid-0b20f4c1-2d0b-4802-87ef-e87cfb8a6f14")}catch{}})();const m={class:"login"},b=i({__name:"Login",setup(e){const o=_();async function s(n){await p.login(),o.push({name:"home"})}return(n,l)=>(c(),d("div",m,[t(a,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const N=f(b,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.6d5dbca4.js.map
