import{d as y,J as h,b as a,c as r,v as l,F as b,K as C,E as F,L as k,y as c,B as v,p as g,ag as u,u as S,o as L,Q as O,A as I,z as D}from"./registerWidgets.4cc86716.js";import{l as R,a as d,b as $,D as A,c as T,i as U,d as W,e as w,L as _,f}from"./colors.267ec6f7.js";const E={key:0,class:"p-steps p-component"},q={class:"p-steps-list"},x={class:"p-menuitem-link"},z={class:"p-steps-number"},B=y({__name:"Steps",props:{stepsInfo:{type:Object,default:null}},setup(e){const t=e,i=h(()=>t.stepsInfo?Array(t.stepsInfo.total).fill(null).map(()=>({label:"",to:""})):[]);return(m,p)=>e.stepsInfo?(a(),r("nav",E,[l("ol",q,[(a(!0),r(b,null,C(c(i),(s,o)=>(a(),r("li",{key:o,class:F(["p-steps-item",{"p-highlight":o+1===e.stepsInfo.current}])},[l("span",x,[l("span",z,k(o+1),1)])],2))),128))])])):v("",!0)}});const X=g(B,[["__scopeId","data-v-c6d9488a"]]),N=e=>`https://fonts.googleapis.com/css2?family=${e.split(" ").join("+")}:wght@300;400;500;700;900&display=swap`;function H(e){return e.startsWith("#")||e.match(/^(rgb|hsl)/)}function j(e){try{return new URL(e),!0}catch{return!1}}function G(e){return j(e)?{backgroundImage:`url(${e})`,backgroundSize:"cover"}:H(e)?{backgroundColor:e}:{backgroundColor:"/_assets/background"}}const K=["theme"],M=["href"],V=y({__name:"WidgetsFrame",props:{theme:{type:String,required:!0},mainColor:{type:String,required:!0},fontFamily:{type:String,required:!0},runtime:{type:String,required:!0,validator:e=>["form","dash"].includes(e)}},setup(e){const t=e,i=u(()=>N(t.fontFamily)),m=u(()=>(typeof document<"u"&&document.documentElement.style.setProperty("--ac-global-font-family",t.fontFamily),{"--color-main":t.mainColor,"--color-main-light":R(t.mainColor,.15),"--color-main-hover":d(t.mainColor),"--color-main-active":d(t.mainColor),"--color-secondary":"transparent","--color-secondary-lighter":"transparent","--color-secondary-darker":"transparent","--button-font-color-main":$(t.mainColor),"--font-family":t.fontFamily,...G(t.theme)})),p=u(()=>t.runtime==="dash"?A:T),s=S({"--font-color":p.value,"--background-color":"transparent"}),o=async()=>{const n=U(t.theme)?await W(t.theme):w(t.theme);s["--font-color"]=n?_:f,s["--background-color"]=n?f:_};return L(o),O(()=>t.theme,o),(n,J)=>(a(),r("div",{class:"frame background-theme",theme:e.theme,style:D({...c(m),...c(s)})},[l("link",{href:c(i),rel:"stylesheet"},null,8,M),I(n.$slots,"default",{},void 0,!0)],12,K))}});const Y=g(V,[["__scopeId","data-v-ca2408ab"]]);export{X as S,Y as W};
//# sourceMappingURL=WidgetsFrame.8a984b59.js.map
