import{u as c}from"./icons.d9ce72d6.js";import{d as u,J as d,H as i,a as p,b as _,c as l,e as f,z as b,S as m,q as y}from"./registerWidgets.0a925ff6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="1b2ca807-a933-41a3-8083-2abef1699b6c",e._sentryDebugIdIdentifier="sentry-dbid-1b2ca807-a933-41a3-8083-2abef1699b6c")}catch{}})();const v=u({__name:"PreviewButton",props:{model:null},setup(e){const t=e,o=d(),s=i(),a=()=>{const n=o.query;s.push({path:`/_editor/${t.model.routeName}/${encodeURIComponent(t.model.path)}/preview`,query:n})};return(n,w)=>{const r=p("icon");return _(),l("button",{class:"preview-button",onClick:a},[f(r,{class:"icon",path:b(c),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),m(" Preview ")])}}});const I=y(v,[["__scopeId","data-v-4b4c109d"]]);export{I as P};
//# sourceMappingURL=PreviewButton.d2007491.js.map
