import{d as f,K as b,b as y,t as g,z as s,J as _}from"./registerWidgets.e8bf9be7.js";import{a as w}from"./asyncComputed.15c1fcc9.js";import"./gateway.52ae1994.js";import{M as i}from"./member.b6bf4a71.js";import{C as I}from"./CrudView.d77460fd.js";import"./passwordlessManager.22684bfc.js";import"./activeRecord.66fd8f56.js";import"./DropdownMenu.546dc055.js";import"./Modal.eeedb03e.js";import"./LoadingIndicator.3b84df59.js";import"./lottie.b4c9148a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="1cba065d-0ed9-4daf-af88-1ec665834de0",e._sentryDebugIdIdentifier="sentry-dbid-1cba065d-0ed9-4daf-af88-1ec665834de0")}catch{}})();const A=f({__name:"Members",setup(e){const o=_().params.organizationId,m=[{key:"email",label:"Email"}],d=async t=>{await i.create(o,t.email),p()},{loading:l,result:c,refetch:p}=w(()=>i.list(o)),u=b(()=>{var t,r;return{columns:[{name:"Email"},{name:"Role"}],rows:(r=(t=c.value)==null?void 0:t.map(n=>({key:n.email,cells:[{text:n.email,classes:["title","centered"]},{text:n.role,classes:["centered"]}]})))!=null?r:[]}});return(t,r)=>(y(),g(I,{"entity-name":"members",loading:s(l),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:s(u),"create-button-text":"Add members",fields:m,onCreate:d},null,8,["loading","table"]))}});export{A as default};
//# sourceMappingURL=Members.33660822.js.map
