import{d as b,K as f,b as y,t as g,z as s,J as _}from"./registerWidgets.c33434b6.js";import{a as w}from"./asyncComputed.2a2efb36.js";import"./gateway.b560ee02.js";import{M as i}from"./member.18ed8e83.js";import{C as I}from"./CrudView.b49f21ed.js";import"./passwordlessManager.dde65e6d.js";import"./activeRecord.cbf414d4.js";import"./DropdownMenu.0269901f.js";import"./Modal.2a79bddf.js";import"./LoadingIndicator.cbc4e2f3.js";import"./lottie.02d4abc1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="8ea2ca4d-69c8-48ba-896c-4770cc47e4e4",e._sentryDebugIdIdentifier="sentry-dbid-8ea2ca4d-69c8-48ba-896c-4770cc47e4e4")}catch{}})();const A=b({__name:"Members",setup(e){const o=_().params.organizationId,m=[{key:"email",label:"Email"}],l=async t=>{await i.create(o,t.email),p()},{loading:c,result:d,refetch:p}=w(()=>i.list(o)),u=f(()=>{var t,r;return{columns:[{name:"Email"},{name:"Role"}],rows:(r=(t=d.value)==null?void 0:t.map(n=>({key:n.email,cells:[{text:n.email,classes:["title","centered"]},{text:n.role,classes:["centered"]}]})))!=null?r:[]}});return(t,r)=>(y(),g(I,{"entity-name":"members",loading:s(c),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:s(u),"create-button-text":"Add members",fields:m,onCreate:l},null,8,["loading","table"]))}});export{A as default};
//# sourceMappingURL=Members.9c19c8f8.js.map
