import{L as t}from"./lottie.61fc86ea.js";import{d as a,r,o as s,b as d,c as i,x as c,B as _,q as f}from"./registerWidgets.f021c1a4.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="01b0e288-9f17-4e8f-98f2-adc9c8713044",n._sentryDebugIdIdentifier="sentry-dbid-01b0e288-9f17-4e8f-98f2-adc9c8713044")}catch{}})();const l={class:"container"},u=a({__name:"LoadingIndicator",setup(n){const e=r(null);return s(()=>{!e.value||t.loadAnimation({container:e.value,renderer:"svg",loop:!0,autoplay:!0,path:"/circularLoading.json"})}),(o,p)=>(d(),i("div",l,[c("div",{ref_key:"animation",ref:e,class:"animation"},null,512),_(o.$slots,"default",{},void 0,!0)]))}});const m=f(u,[["__scopeId","data-v-c30401d8"]]);export{m as L};
//# sourceMappingURL=LoadingIndicator.a872de61.js.map
