import{d as u,K as m,b as _,t as f,w as b,z as d,J as y,O as g,Q as h,x as i,S as n,q as w}from"./registerWidgets.0e006b6f.js";import{a as I}from"./asyncComputed.62aacf33.js";import"./gateway.68890283.js";import{B as x}from"./build.5052b3de.js";import"./index.699f7fd0.js";import{C as v}from"./CrudView.ce48083b.js";import"./passwordlessManager.4cf24a2b.js";import"./pubsub.13db2123.js";import"./activeRecord.d399634f.js";import"./DropdownMenu.a8ccd533.js";import"./Modal.d54926bb.js";import"./LoadingIndicator.8b9ec224.js";import"./lottie.b974d0b6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="76f957b0-8004-4936-b8d2-5aefe119765a",e._sentryDebugIdIdentifier="sentry-dbid-76f957b0-8004-4936-b8d2-5aefe119765a")}catch{}})();const B=e=>(g("data-v-1b7a68a8"),e=e(),h(),e),C=B(()=>i("div",{class:"instructions"},[n(" Get started with the local editor in seconds: "),i("pre",null,`    $ pip install abstra --upgrade
    $ abstra serve ./your-project-directory
    `),n(" And you're done! Explore the local editor and start building apps. ")],-1)),S=u({__name:"Builds",setup(e){const r=y().params.projectId,{loading:p,result:c}=I(()=>x.list(r)),l=m(()=>{var a,s;return{columns:[{name:"Id"},{name:"Creation date"},{name:"Status"}],rows:(s=(a=c.value)==null?void 0:a.map(t=>({key:t.id,cells:[{text:t.id,classes:["title","centered"]},{text:t.createdAt.toLocaleString(),classes:[]},{text:t.status,classes:["centered"]}]})))!=null?s:[]}});return(a,s)=>(_(),f(v,{"entity-name":"build",loading:d(p),title:"Builds",description:"Each build is a version of your app. You can create a new build by deploying your app from the local editor.","empty-title":"No builds here yet",table:d(l)},{"empty-description":b(()=>[C]),_:1},8,["loading","table"]))}});const L=w(S,[["__scopeId","data-v-1b7a68a8"]]);export{L as default};
//# sourceMappingURL=Builds.65f17c28.js.map
