import{P as r}from"./Passwordless.6b642399.js";import{N as a}from"./Navbar.bbfdac3f.js";import{d,b as c,c as i,e as t,H as _,q as p}from"./registerWidgets.29e41a54.js";import{M as f}from"./member.75a22a37.js";import"./CircularLoading.0d1cd4f5.js";import"./icons.b931f659.js";import"./passwordlessManager.88f105f1.js";import"./logo.084e5d7c.js";import"./asyncComputed.0126d7e4.js";import"./gateway.dfba55d6.js";import"./activeRecord.d63d0be1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="110412ce-0220-48d5-b8b3-56bd774cf0f3",e._sentryDebugIdIdentifier="sentry-dbid-110412ce-0220-48d5-b8b3-56bd774cf0f3")}catch{}})();const m={class:"login"},b=d({__name:"Login",setup(e){const o=_();async function s(n){await f.login(),o.push({name:"home"})}return(n,l)=>(c(),i("div",m,[t(a,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const M=p(b,[["__scopeId","data-v-c9b2b4e6"]]);export{M as default};
//# sourceMappingURL=Login.cb7490ea.js.map
