import{S as p}from"./Sidebar.8d4d471d.js";import{N as m}from"./Navbar.bbfdac3f.js";import{F as l,G as u,H as _}from"./icons.b931f659.js";import{d as b,K as f,b as g,c as v,e as t,z as s,x as r,w as y,F as h,J as w,a as z,O as I,Q as O,q as x}from"./registerWidgets.29e41a54.js";import{a as S}from"./asyncComputed.0126d7e4.js";import"./gateway.dfba55d6.js";import{O as k}from"./organization.252003ea.js";import"./Tooltip.1c0158ea.js";import"./logo.084e5d7c.js";import"./passwordlessManager.88f105f1.js";import"./activeRecord.d63d0be1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="3407106f-5bad-440c-8ae7-fdddd76e8e48",e._sentryDebugIdIdentifier="sentry-dbid-3407106f-5bad-440c-8ae7-fdddd76e8e48")}catch{}})();const B=e=>(I("data-v-580769d7"),e=e(),O(),e),C={class:"organization"},D=B(()=>r("div",null,"div",-1)),N=b({__name:"Organization",setup(e){const n=w().params.organizationId,{result:o}=S(()=>k.get(n)),i=f(()=>o.value?[{label:o.value.name,path:`/organizations/${o.value.id}`}]:void 0),d=[{name:"Organization",items:[{name:"Projects",icon:l,path:"projects"},{name:"Members",icon:u,path:"members"},{name:"Billing",icon:_,path:"billing",unavailable:!0}]}];return(F,j)=>{const c=z("router-view");return g(),v(h,null,[t(m,{breadcrumb:s(i)},null,8,["breadcrumb"]),r("div",C,[t(p,{class:"sidebar",sections:s(d)},{default:y(()=>[D]),_:1},8,["sections"]),t(c)])],64)}}});const $=x(N,[["__scopeId","data-v-580769d7"]]);export{$ as default};
//# sourceMappingURL=Organization.633f667f.js.map
