import{d as o,b as c,c as f,q as _}from"./registerWidgets.68572380.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="f5ef1710-2193-412f-82eb-48c6f0134232",e._sentryDebugIdIdentifier="sentry-dbid-f5ef1710-2193-412f-82eb-48c6f0134232")}catch{}})();const a=["href"],r=o({__name:"DocsButton",props:{path:null},setup(e){return(t,n)=>{var s;return c(),f("a",{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank"}," Docs ",8,a)}}});const u=_(r,[["__scopeId","data-v-9fec5678"]]);export{u as D};
//# sourceMappingURL=DocsButton.a49e24b4.js.map
