[data-v-dde58483]:root{--main-font-family: DM Sans, sans-serif}[data-v-dde58483]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-dde58483]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-dde58483]{background-color:#fff;padding:10px}.loading[data-v-dde58483]{position:absolute;top:0;left:0;right:0;bottom:0;display:flex;align-items:center}
