import{q as t,b as s,c as o}from"./registerWidgets.0897334f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="b9775e58-efa4-4826-a116-52635f6b3608",e._sentryDebugIdIdentifier="sentry-dbid-b9775e58-efa4-4826-a116-52635f6b3608")}catch{}})();const r={},a={class:"organization-settings"};function i(e,n){return s(),o("div",a,"Organization settings")}const c=t(r,[["render",i]]);export{c as default};
//# sourceMappingURL=OrganizationSettings.415ae4c1.js.map
