import{L as c}from"./lottie.314baab9.js";import{d as u,r as f,o as p,K as s,b as _,c as y,x as b,A as a,z as i,B as g,q as m}from"./registerWidgets.2bf05ebf.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="107b9376-bbf5-479e-b5c8-8dd04001e57b",e._sentryDebugIdIdentifier="sentry-dbid-107b9376-bbf5-479e-b5c8-8dd04001e57b")}catch{}})();const v=u({__name:"CircularLoading",props:{direction:null,justify:null,size:null},setup(e){const t=e,o=f(null);p(()=>{!o.value||c.loadAnimation({container:o.value,renderer:"svg",loop:!0,autoplay:!0,path:"/circularLoading.json"})});const d=s(()=>{const{direction:n="row",justify:r="space-between"}=t;return{flexDirection:n,justifyContent:r}}),l=s(()=>{const{size:n="40"}=t;return{width:`${n}px`,height:`${n}px`}});return(n,r)=>(_(),y("div",{class:"container",style:a(i(d))},[b("div",{ref_key:"loading",ref:o,style:a(i(l))},null,4),g(n.$slots,"default",{},void 0,!0)],4))}});const I=m(v,[["__scopeId","data-v-a1f994d4"]]);export{I as L};
//# sourceMappingURL=CircularLoading.241c7a75.js.map
