import{d as b,K as f,b as y,t as g,z as s,J as _}from"./registerWidgets.eddc32f4.js";import{a as w}from"./asyncComputed.562c187e.js";import"./gateway.7d65591c.js";import{M as i}from"./member.f4bff51a.js";import{C as I}from"./CrudView.4dc213ee.js";import"./passwordlessManager.8b97cbcd.js";import"./activeRecord.ed4e0294.js";import"./DropdownMenu.07e05b99.js";import"./Modal.bb1eb9c5.js";import"./LoadingIndicator.f662ca6a.js";import"./lottie.6d443700.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="ad21fa23-0c15-4106-a479-44c9b159c830",e._sentryDebugIdIdentifier="sentry-dbid-ad21fa23-0c15-4106-a479-44c9b159c830")}catch{}})();const A=b({__name:"Members",setup(e){const o=_().params.organizationId,m=[{key:"email",label:"Email"}],l=async t=>{await i.create(o,t.email),p()},{loading:c,result:d,refetch:p}=w(()=>i.list(o)),u=f(()=>{var t,r;return{columns:[{name:"Email"},{name:"Role"}],rows:(r=(t=d.value)==null?void 0:t.map(n=>({key:n.email,cells:[{text:n.email,classes:["title","centered"]},{text:n.role,classes:["centered"]}]})))!=null?r:[]}});return(t,r)=>(y(),g(I,{"entity-name":"members",loading:s(c),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:s(u),"create-button-text":"Add members",fields:m,onCreate:l},null,8,["loading","table"]))}});export{A as default};
//# sourceMappingURL=Members.df081e1f.js.map
