import{d as b,K as i,b as _,c as g,e as s,z as c,x as l,F as v,J as f,a as y,q as h}from"./registerWidgets.05268d5e.js";import{a as d}from"./asyncComputed.8f90be18.js";import{P as I}from"./project.79348d50.js";import"./gateway.c44af888.js";import{O as j}from"./organization.45bbed38.js";import{N as z}from"./Navbar.44f2c4a6.js";import{S as w}from"./Sidebar.a5a2646a.js";import{I as P,E as k,J as x,K as B,L as $,F as D,G as E,H as N}from"./icons.7c77483f.js";import"./activeRecord.bacc466b.js";import"./passwordlessManager.61e5b6aa.js";import"./logo.084e5d7c.js";import"./Tooltip.c8791c24.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[o]="5c8e7872-e7d2-47bd-b550-7207cbec304d",a._sentryDebugIdIdentifier="sentry-dbid-5c8e7872-e7d2-47bd-b550-7207cbec304d")}catch{}})();const S={class:"project"},C={class:"content-wrapper"},F=b({__name:"Project",setup(a){const r=f().params.projectId,{result:e}=d(()=>I.get(r)),{result:t}=d(()=>e.value?j.get(e.value.organizationId):Promise.resolve(null)),p=i(()=>{var n;return t.value&&e.value?[{label:(n=t.value)==null?void 0:n.name,path:`/organizations/${t.value.id}`},{label:e.value.name,path:`/projects/${e.value.id}`}]:void 0}),m=i(()=>e.value?[{name:"Project",items:[{name:"Builds",path:"builds",icon:P},{name:"API Keys",path:"api-keys",icon:k},{name:"Env Vars",path:"env-vars",icon:x},{name:"Logs",icon:B,path:"logs",beta:!0},{name:"Settings",icon:$,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:D,path:`/organizations/${e.value.organizationId}/projects`},{name:"Members",icon:E,path:`/organizations/${e.value.organizationId}/members`},{name:"Billing",icon:N,path:`/organizations/${e.value.organizationId}/billing`,unavailable:!0}]}]:[]);return(n,K)=>{const u=y("router-view");return _(),g(v,null,[s(z,{class:"nav",breadcrumb:c(p)},null,8,["breadcrumb"]),l("div",S,[s(w,{class:"sidebar",sections:c(m)},null,8,["sections"]),l("div",C,[s(u)])])],64)}}});const U=h(F,[["__scopeId","data-v-cfb4011f"]]);export{U as default};
//# sourceMappingURL=Project.181b9a99.js.map
