import{x as s}from"./icons.b993259e.js";import{d as r,a as c,b as i,c as d,e as _,z as f,S as l,q as u}from"./registerWidgets.f021c1a4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="f549e15e-918c-46fe-b9ba-a639171f45e6",e._sentryDebugIdIdentifier="sentry-dbid-f549e15e-918c-46fe-b9ba-a639171f45e6")}catch{}})();const p=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const a=c("icon");return i(),d("button",{class:"back-btn",onClick:n[0]||(n[0]=b=>t("exitFullscreenPreview"))},[_(a,{class:"icon",path:f(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),l(" Editor ")])}}});const w=u(p,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.80cc74bf.js.map
