import{d as v,x as f,u as _,b as c,c as d,v as r,y as m,z as s,A as i,B as S,D as O,E as b,q as k}from"./registerWidgets.fff064a1.js";const h=v({__name:"Modal",props:{containerStyle:{type:Object,default:()=>({})},headerStyle:{type:Object,default:()=>({})},contentStyle:{type:Object,default:()=>({})}},emits:["open","close"],setup(e,{expose:p,emit:a}){const y=()=>{t.isOpened=!0,a("open")},o=()=>{t.isOpened=!1,a("close")},u=f();p({open:y,close:o});const t=_({isOpened:!1});return(n,l)=>(c(),d("div",{class:b(["background",t.isOpened&&"visible"]),onClick:o},[r("div",{class:"container",style:s(e.containerStyle),onClick:l[0]||(l[0]=O(()=>{},["stop"]))},[m(u).header?(c(),d("div",{key:0,class:"header",style:s(e.headerStyle)},[i(n.$slots,"header",{},void 0,!0)],4)):S("",!0),r("div",{class:"content",style:s(e.contentStyle)},[i(n.$slots,"content",{},void 0,!0)],4)],4)],2))}});const M=k(h,[["__scopeId","data-v-0ed99ca1"]]);export{M};
//# sourceMappingURL=Modal.2ceba592.js.map
