import{d as o,b as a,c,q as f}from"./registerWidgets.29e41a54.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="8c1af260-962a-449f-a9fb-08ff6bdbdfe1",e._sentryDebugIdIdentifier="sentry-dbid-8c1af260-962a-449f-a9fb-08ff6bdbdfe1")}catch{}})();const d=["href"],_=o({__name:"DocsButton",props:{path:null},setup(e){return(t,n)=>{var s;return a(),c("a",{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank"}," Docs ",8,d)}}});const u=f(_,[["__scopeId","data-v-9fec5678"]]);export{u as D};
//# sourceMappingURL=DocsButton.796bbb82.js.map
