import{x as a}from"./icons.0b88355c.js";import{d as r,a as c,b as i,c as d,e as _,z as l,S as b,q as u}from"./registerWidgets.ef15081f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="8e572072-6b68-4f33-81ba-e8b4c166b1e0",e._sentryDebugIdIdentifier="sentry-dbid-8e572072-6b68-4f33-81ba-e8b4c166b1e0")}catch{}})();const f=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const s=c("icon");return i(),d("button",{class:"back-btn",onClick:n[0]||(n[0]=p=>t("exitFullscreenPreview"))},[_(s,{class:"icon",path:l(a),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),b(" Editor ")])}}});const w=u(f,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.35697b02.js.map
