import{q as r,a,b as c,t as i,f as d,g as p,_,h as u,k as f,T as l,P as h,C as b,M as g,s as y,i as m,j as s,l as w,m as v,n as k}from"./registerWidgets.7cf0d33e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ffcbc634-3afc-4c3e-859e-d9857939c9eb",e._sentryDebugIdIdentifier="sentry-dbid-ffcbc634-3afc-4c3e-859e-d9857939c9eb")}catch{}})();const I={};function x(e,t){const o=a("router-view");return c(),i(o,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=r(I,[["render",x]]),n=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.8f66d393.js"),["assets/Player.8f66d393.js","assets/index.2b2e98e0.js","assets/registerWidgets.7cf0d33e.js","assets/registerWidgets.a7e6ab4f.css","assets/log.6b189859.js","assets/broker.d7213073.js","assets/passwordlessManager.319d982e.js","assets/icons.5faf907f.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.a07ae91e.js","assets/Passwordless.1bb495c6.js","assets/CircularLoading.252e5f3b.js","assets/lottie.adcbdb1d.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/executeJs.df044343.js","assets/PlayerNavbar.4bce3b06.js","assets/PlayerNavbar.1542e7ca.css","assets/WidgetsFrame.b81b277b.js","assets/colors.3380771c.js","assets/WidgetsFrame.701a818b.css","assets/Modal.f8435634.js","assets/Modal.5aaf8eba.css","assets/executeJs.b0d1ede9.css","assets/broker.f87ad36d.css","assets/DashPlayer.44945ec3.js","assets/runnerData.a3a3f9aa.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.0ce7cae2.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=u({render:()=>f(A)});l.init(),e.use(n),e.use(h),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",g),e.component("Message",y),m(e,n),s(e,w),s(e,v),s(e,k)};D();
//# sourceMappingURL=player.b6149ce3.js.map
