import{P as r}from"./Passwordless.6c7a116b.js";import{N as a}from"./Navbar.03b5b117.js";import{d as i,b as c,c as d,e as t,H as _,q as p}from"./registerWidgets.68572380.js";import{M as m}from"./member.cfc3d34b.js";import"./CircularLoading.30fd4d73.js";import"./lottie.e503152f.js";import"./icons.3acf9dc1.js";import"./passwordlessManager.8fb0aebd.js";import"./logo.084e5d7c.js";import"./asyncComputed.896b7bde.js";import"./gateway.7cd64c5e.js";import"./activeRecord.15082700.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="65c8643e-ce1e-4e5b-9799-8db43bb06e2e",e._sentryDebugIdIdentifier="sentry-dbid-65c8643e-ce1e-4e5b-9799-8db43bb06e2e")}catch{}})();const b={class:"login"},l=i({__name:"Login",setup(e){const o=_();async function s(n){await m.login(),o.push({name:"home"})}return(n,f)=>(c(),d("div",b,[t(a,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const N=p(l,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.1e724be9.js.map
