import{P as r}from"./Passwordless.84c9704e.js";import{N as a}from"./Navbar.851febbe.js";import{d,b as i,c,e as t,H as _,q as p}from"./registerWidgets.553de467.js";import{M as m}from"./member.2fe0e01a.js";import"./CircularLoading.01ebf7ca.js";import"./lottie.433e3d0f.js";import"./icons.012820f9.js";import"./passwordlessManager.b79493a6.js";import"./logo.084e5d7c.js";import"./asyncComputed.2769eba5.js";import"./gateway.55889fdc.js";import"./activeRecord.5283a3fc.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="2539fc51-60ed-4eb7-a5b1-2b371a60d875",e._sentryDebugIdIdentifier="sentry-dbid-2539fc51-60ed-4eb7-a5b1-2b371a60d875")}catch{}})();const f={class:"login"},b=d({__name:"Login",setup(e){const o=_();async function s(n){await m.login(),o.push({name:"home"})}return(n,l)=>(i(),c("div",f,[t(a,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const N=p(b,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.bfac7d79.js.map
