import{q as t,b as s,c as d}from"./registerWidgets.0a925ff6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="79eb159b-5d15-4d01-a615-9a0789c4f6d8",e._sentryDebugIdIdentifier="sentry-dbid-79eb159b-5d15-4d01-a615-9a0789c4f6d8")}catch{}})();const o={},r={class:"organization-settings"};function a(e,n){return s(),d("div",r,"Organization settings")}const f=t(o,[["render",a]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.21c96d63.js.map
