[data-v-f4ca2d64]:root{--main-font-family: DM Sans, sans-serif}[data-v-f4ca2d64]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.sidebar-editor[data-v-f4ca2d64]{display:flex;flex-direction:column;width:100%;overflow:auto;gap:1rem;align-items:center}.sidebar-editor[data-v-f4ca2d64] .sidebar-item{display:flex;justify-content:space-between}.sidebar-editor[data-v-f4ca2d64] .sidebar-item .property{display:flex;gap:.5rem;align-items:center;width:100%;height:100%;padding:.5rem}.sidebar-editor[data-v-f4ca2d64] .sidebar-item .property .property-name,.sidebar-editor[data-v-f4ca2d64] .sidebar-item .property .property-value{font-size:.8rem;color:var(--vscode-editor-foreground, #8692a5)}.sidebar-editor[data-v-f4ca2d64] .sidebar-item .property .property-name{font-weight:500}.sidebar-editor[data-v-f4ca2d64] .draggable{cursor:move}[data-v-c55f20f4]:root{--main-font-family: DM Sans, sans-serif}[data-v-c55f20f4]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.sidebar-editor[data-v-c55f20f4]{width:960px;max-width:calc(100vw - 40px);align-self:flex-start;box-sizing:border-box;overflow:auto;display:flex;flex-direction:column;gap:30px}.sidebar-editor h1[data-v-c55f20f4],.sidebar-editor h2[data-v-c55f20f4]{font-size:1.5rem;margin:0;color:#5a677a}
