import{P as a}from"./Passwordless.15d9e658.js";import{N as r}from"./Navbar.607b72f5.js";import{d as n,b as _,c as i,e as o,H as p,q as c}from"./registerWidgets.7452ec0b.js";import{M as m}from"./member.62e0f586.js";import"./CircularLoading.6725993e.js";import"./icons.97625e56.js";import"./passwordlessManager.abb9ad15.js";import"./logo.084e5d7c.js";import"./asyncComputed.23d75013.js";import"./utils.e51f765d.js";import"./pubsub.a0411919.js";const d={class:"login"},l=n({__name:"Login",setup(f){const e=p();async function s(t){await m.login(),e.push({name:"home"})}return(t,u)=>(_(),i("div",d,[o(r,{class:"nav"}),o(a,{class:"passwordless",onDone:s})]))}});const B=c(l,[["__scopeId","data-v-64286f28"]]);export{B as default};
//# sourceMappingURL=Login.84de29d1.js.map
