import{q as r,a,b as i,t as c,f as d,g as p,_,h as u,k as l,T as f,P as h,C as g,M as y,s as m,i as w,j as s,l as b,m as v,n as k}from"./registerWidgets.05268d5e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="87d24f23-2669-4043-8d73-1cec2c096683",e._sentryDebugIdIdentifier="sentry-dbid-87d24f23-2669-4043-8d73-1cec2c096683")}catch{}})();const I={};function x(e,t){const o=a("router-view");return i(),c(o,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=r(I,[["render",x]]),n=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.486eb509.js"),["assets/Player.486eb509.js","assets/index.eab4f300.js","assets/registerWidgets.05268d5e.js","assets/registerWidgets.448db7e9.css","assets/log.c389d378.js","assets/broker.74421085.js","assets/passwordlessManager.61e5b6aa.js","assets/icons.7c77483f.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.0b189a46.js","assets/Passwordless.272e470d.js","assets/CircularLoading.b36562a7.js","assets/lottie.ea647b01.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/executeJs.61bf027f.js","assets/PlayerNavbar.d7b76127.js","assets/PlayerNavbar.b27e2024.css","assets/WidgetsFrame.747ab74f.js","assets/colors.c1c56c5b.js","assets/WidgetsFrame.701a818b.css","assets/Modal.ab17c1cc.js","assets/Modal.5aaf8eba.css","assets/executeJs.b0d1ede9.css","assets/broker.f87ad36d.css","assets/DashPlayer.48ce6b09.js","assets/runnerData.dd957d35.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.8f90be18.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=u({render:()=>l(A)});f.init(),e.use(n),e.use(h),e.mount("#app"),e.component("VSelect",g),e.component("Markdown",y),e.component("Message",m),w(e,n),s(e,b),s(e,v),s(e,k)};D();
//# sourceMappingURL=player.fd8ab642.js.map
