import{d as o,b as c,c as a,q as d}from"./registerWidgets.ad696c68.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="aac76657-4780-41dc-ab3b-e2cce0998feb",e._sentryDebugIdIdentifier="sentry-dbid-aac76657-4780-41dc-ab3b-e2cce0998feb")}catch{}})();const _=["href"],r=o({__name:"DocsButton",props:{path:null},setup(e){return(t,n)=>{var s;return c(),a("a",{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank"}," Docs ",8,_)}}});const u=d(r,[["__scopeId","data-v-9fec5678"]]);export{u as D};
//# sourceMappingURL=DocsButton.3f80ab35.js.map
