import{q as t,b as s,c as a}from"./registerWidgets.db466a36.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="3149c4f6-3b6f-41d2-88ea-ba89c21aab10",e._sentryDebugIdIdentifier="sentry-dbid-3149c4f6-3b6f-41d2-88ea-ba89c21aab10")}catch{}})();const o={},r={class:"organization-settings"};function c(e,n){return s(),a("div",r,"Organization settings")}const f=t(o,[["render",c]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.47082616.js.map
