import{q as t,b as s,c}from"./registerWidgets.e8bf9be7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="80237a3b-b8fe-4055-9cde-56c89d2a8c93",e._sentryDebugIdIdentifier="sentry-dbid-80237a3b-b8fe-4055-9cde-56c89d2a8c93")}catch{}})();const o={},r={class:"organization-settings"};function a(e,n){return s(),c("div",r,"Organization settings")}const f=t(o,[["render",a]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.2ecdd907.js.map
