import{S as p}from"./Sidebar.904442d0.js";import{N as m}from"./Navbar.02110df4.js";import{F as d,G as l,H as _}from"./icons.d4e872e2.js";import{d as u,J as b,b as v,c as g,e,y as t,v as s,w as f,F as h,H as z,a as O,N as w,O as I,p as S}from"./registerWidgets.990552e9.js";import{a as x}from"./asyncComputed.5a7faf96.js";import"./gateway.4e567afc.js";import{O as y}from"./organization.2f48c54d.js";import"./Tooltip.9340b3bf.js";import"./logo.084e5d7c.js";import"./passwordlessManager.43e7eeb6.js";import"./activeRecord.57c6bf02.js";const N=a=>(w("data-v-580769d7"),a=a(),I(),a),B={class:"organization"},C=N(()=>s("div",null,"div",-1)),k=u({__name:"Organization",setup(a){const n=z().params.organizationId,{result:o}=x(()=>y.get(n)),r=b(()=>o.value?[{label:o.value.name,path:`/organizations/${o.value.id}`}]:void 0),i=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:_,path:"billing",unavailable:!0}]}];return(j,H)=>{const c=O("router-view");return v(),g(h,null,[e(m,{breadcrumb:t(r)},null,8,["breadcrumb"]),s("div",B,[e(p,{class:"sidebar",sections:t(i)},{default:f(()=>[C]),_:1},8,["sections"]),e(c)])],64)}}});const K=S(k,[["__scopeId","data-v-580769d7"]]);export{K as default};
//# sourceMappingURL=Organization.16071a00.js.map
