import{P as r}from"./Passwordless.89fc3fc4.js";import{N as a}from"./Navbar.4071bc21.js";import{d,b as i,c,e as t,H as _,q as p}from"./registerWidgets.9f96e537.js";import{M as m}from"./member.0995ac01.js";import"./CircularLoading.c1f8d14a.js";import"./lottie.2c3db159.js";import"./icons.4255d62c.js";import"./passwordlessManager.5f237f08.js";import"./logo.084e5d7c.js";import"./asyncComputed.0a45b9d8.js";import"./gateway.052cd6ee.js";import"./activeRecord.81c11d03.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="9c2283ab-45bd-4426-bed6-33f502c01923",e._sentryDebugIdIdentifier="sentry-dbid-9c2283ab-45bd-4426-bed6-33f502c01923")}catch{}})();const f={class:"login"},b=d({__name:"Login",setup(e){const o=_();async function s(n){await m.login(),o.push({name:"home"})}return(n,l)=>(i(),c("div",f,[t(a,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const N=p(b,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.358a1f38.js.map
