import{M as s}from"./Modal.5e63635f.js";import{d as r,v as c,r as d,b as _,c as l,e as a,w as f,F as b,a as i,x as m,q as u}from"./registerWidgets.2bf05ebf.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="e95d6b6a-94b4-4bb5-b7a5-272faa57c667",e._sentryDebugIdIdentifier="sentry-dbid-e95d6b6a-94b4-4bb5-b7a5-272faa57c667")}catch{}})();const p=["src"],y=r({__name:"Home",setup(e){const o=c({onboardingForm:""}),t=d(null);return(g,v)=>{const n=i("router-view");return _(),l(b,null,[a(n,{class:"router"}),a(s,{ref_key:"modal",ref:t},{content:f(()=>[m("iframe",{class:"form",src:o.onboardingForm},null,8,p)]),_:1},512)],64)}}});const I=u(y,[["__scopeId","data-v-8c8bc27e"]]);export{I as default};
//# sourceMappingURL=Home.37c0bf47.js.map
