import{d as u,K as f,b as m,t as _,w as b,z as r,J as y,O as g,Q as h,x as i,S as n,q as w}from"./registerWidgets.0897334f.js";import{a as I}from"./asyncComputed.14546baa.js";import"./gateway.2c5d8b88.js";import{B as x}from"./build.8f2a7f22.js";import{C as v}from"./CrudView.e6493ca2.js";import"./passwordlessManager.1a21d377.js";import"./activeRecord.6320d31c.js";import"./DropdownMenu.a2eca68d.js";import"./Modal.34822eca.js";import"./LoadingIndicator.c95ba7fd.js";import"./lottie.ffe66724.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="f7de7bd1-98ff-4b93-b5df-6cc95d491ef7",e._sentryDebugIdIdentifier="sentry-dbid-f7de7bd1-98ff-4b93-b5df-6cc95d491ef7")}catch{}})();const B=e=>(g("data-v-1b7a68a8"),e=e(),h(),e),C=B(()=>i("div",{class:"instructions"},[n(" Get started with the local editor in seconds: "),i("pre",null,`    $ pip install abstra --upgrade
    $ abstra serve ./your-project-directory
    `),n(" And you're done! Explore the local editor and start building apps. ")],-1)),S=u({__name:"Builds",setup(e){const d=y().params.projectId,{loading:c,result:p}=I(()=>x.list(d)),l=f(()=>{var s,a;return{columns:[{name:"Id"},{name:"Creation date"},{name:"Status"}],rows:(a=(s=p.value)==null?void 0:s.map(t=>({key:t.id,cells:[{text:t.id,classes:["title","centered"]},{text:t.createdAt.toLocaleString(),classes:[]},{text:t.status,classes:["centered"]}]})))!=null?a:[]}});return(s,a)=>(m(),_(v,{"entity-name":"build",loading:r(c),title:"Builds",description:"Each build is a version of your app. You can create a new build by deploying your app from the local editor.","empty-title":"No builds here yet",table:r(l)},{"empty-description":b(()=>[C]),_:1},8,["loading","table"]))}});const J=w(S,[["__scopeId","data-v-1b7a68a8"]]);export{J as default};
//# sourceMappingURL=Builds.19047591.js.map
