import{q as t,b as s,c as a}from"./registerWidgets.bbbd3e16.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="f4d664e6-98b9-4c27-b16a-6a6994a27343",e._sentryDebugIdIdentifier="sentry-dbid-f4d664e6-98b9-4c27-b16a-6a6994a27343")}catch{}})();const o={},r={class:"organization-settings"};function i(e,n){return s(),a("div",r,"Organization settings")}const f=t(o,[["render",i]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.0950325b.js.map
