import{d,r as i,o as c,a3 as l,b as u,c as f,N as y,ad as b}from"./registerWidgets.5e258592.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="3e02a9c8-1390-47ea-bd52-a9920f56cc8a",e._sentryDebugIdIdentifier="sentry-dbid-3e02a9c8-1390-47ea-bd52-a9920f56cc8a")}catch{}})();const g=d({__name:"ActionButton",props:{action:null},emits:["next"],setup(e,{emit:n}){const o=e,a=i(null);c(()=>{a.value&&o.action.setElement(a.value),l.addAction(o.action)});const s=()=>n("next");return(m,t)=>(u(),f("button",{ref_key:"element",ref:a,class:"next-button",onClick:t[0]||(t[0]=r=>s()),onKeydown:t[1]||(t[1]=b(r=>s(),["enter"]))},y(e.action.name),545))}});export{g as _};
//# sourceMappingURL=ActionButton.vue_vue_type_script_setup_true_lang.3f03b2a5.js.map
