import{r as a,K as d,R as v}from"./registerWidgets.39370cce.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="019eb2cc-f9ce-46df-9271-a64c60812fcd",e._sentryDebugIdIdentifier="sentry-dbid-019eb2cc-f9ce-46df-9271-a64c60812fcd")}catch{}})();const y=e=>{const t=a(Date.now()),l=a(!0),r=a(null),u=a(null),c=d(()=>(t.value,e())),o=n=>{r.value=n,u.value=null,l.value=!1},s=n=>{u.value=n,r.value=null,l.value=!1},f=()=>{t.value=Date.now()};return v(()=>c.value,()=>{r.value=null,l.value=!0,c.value.then(o).catch(n=>{console.error(n),s(n)})}),c.value.then(o),{result:r,loading:l,error:u,refetch:f}};export{y as a};
//# sourceMappingURL=asyncComputed.588e6ddd.js.map
