import{d as o,b as c,c as a,q as _}from"./registerWidgets.05268d5e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="90a8f4b7-c7f6-4828-9c31-b40e1b5b9581",e._sentryDebugIdIdentifier="sentry-dbid-90a8f4b7-c7f6-4828-9c31-b40e1b5b9581")}catch{}})();const r=["href"],d=o({__name:"DocsButton",props:{path:null},setup(e){return(t,n)=>{var s;return c(),a("a",{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank"}," Docs ",8,r)}}});const b=_(d,[["__scopeId","data-v-9fec5678"]]);export{b as D};
//# sourceMappingURL=DocsButton.d997e951.js.map
