import{L as t}from"./lottie.b974d0b6.js";import{d as a,r,o as s,b as d,c as i,x as c,B as f,q as _}from"./registerWidgets.0e006b6f.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="e8c154f4-95b1-4b1c-812f-f61cb4d417fa",n._sentryDebugIdIdentifier="sentry-dbid-e8c154f4-95b1-4b1c-812f-f61cb4d417fa")}catch{}})();const l={class:"container"},u=a({__name:"LoadingIndicator",setup(n){const e=r(null);return s(()=>{!e.value||t.loadAnimation({container:e.value,renderer:"svg",loop:!0,autoplay:!0,path:"/circularLoading.json"})}),(o,p)=>(d(),i("div",l,[c("div",{ref_key:"animation",ref:e,class:"animation"},null,512),f(o.$slots,"default",{},void 0,!0)]))}});const g=_(u,[["__scopeId","data-v-c30401d8"]]);export{g as L};
//# sourceMappingURL=LoadingIndicator.8b9ec224.js.map
