import{M as r}from"./Modal.eeedb03e.js";import{d as a,v as c,r as d,b as _,c as l,e as n,w as i,F as f,a as m,x as u,q as b}from"./registerWidgets.e8bf9be7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="145749b6-27e4-4390-8be1-7b43d8a50298",e._sentryDebugIdIdentifier="sentry-dbid-145749b6-27e4-4390-8be1-7b43d8a50298")}catch{}})();const p=["src"],y=a({__name:"Home",setup(e){const o=c({onboardingForm:""}),t=d(null);return(g,v)=>{const s=m("router-view");return _(),l(f,null,[n(s,{class:"router"}),n(r,{ref_key:"modal",ref:t},{content:i(()=>[u("iframe",{class:"form",src:o.onboardingForm},null,8,p)]),_:1},512)],64)}}});const I=b(y,[["__scopeId","data-v-8c8bc27e"]]);export{I as default};
//# sourceMappingURL=Home.c820efa3.js.map
