.background-theme[data-v-09ca60c8]{background-repeat:no-repeat;background-size:cover;background-position:center}.sidebar[data-v-09ca60c8]{position:absolute;top:48px;left:0;bottom:0;display:flex;flex-direction:column;padding:0;gap:2rem;width:0px;background:rgba(255,255,255,.8);box-shadow:4px 8px 4px #00000005;transition:width .3s ease-out;box-sizing:border-box;z-index:2}.sidebar.open[data-v-09ca60c8]{width:15rem;align-items:flex-start;padding:12px}@media screen and (min-width: 1200px){.sidebar.dash[data-v-09ca60c8]:not(.desktop){width:15rem;align-items:flex-start;padding:12px}.sidebar.dash:not(.desktop) .sidebar-content .item>.item-title[data-v-09ca60c8]{display:unset;color:#49454f}.sidebar.dash:not(.desktop) .sidebar-content .active>.item-title[data-v-09ca60c8]{display:unset;color:var(--color-main)}}.sidebar.dash.mobile[data-v-09ca60c8]{padding:0}.sidebar.dash.mobile[data-v-09ca60c8]:not(.open){width:0px!important}.sidebar.dash.mobile.open[data-v-09ca60c8]{width:15rem;align-items:flex-start;padding:12px}.sidebar .current[data-v-09ca60c8]{display:flex;flex-direction:row;align-items:center;justify-content:space-between;width:100%}.sidebar .current .item-title[data-v-09ca60c8]{font-family:var(--font-family);font-style:normal;font-weight:500;font-size:14px;line-height:20px;letter-spacing:.1px;color:#222}.sidebar .sidebar-content[data-v-09ca60c8]{display:flex;flex-direction:column;overflow:auto;width:100%}.sidebar .sidebar-content .item[data-v-09ca60c8]{min-height:unset;cursor:pointer;padding:1rem;box-sizing:border-box;display:flex;gap:1rem;align-items:center;justify-content:flex-start;border-radius:4px}.sidebar .sidebar-content .item .item-title[data-v-09ca60c8]{font-family:var(--font-family);font-style:normal;font-weight:500;font-size:14px;line-height:20px;letter-spacing:.1px;display:none}.sidebar .sidebar-content .item .item-title.open[data-v-09ca60c8]{display:unset;color:#49454f}.sidebar .sidebar-content .item[data-v-09ca60c8]:hover{background:rgba(0,0,0,.0196078431)}.sidebar .sidebar-content .item[data-v-09ca60c8] :active{background:rgba(0,0,0,.0784313725)}.sidebar .sidebar-content .item :active .item-title[data-v-09ca60c8]{color:var(--color-main)}.sidebar .sidebar-content .active[data-v-09ca60c8]{background:rgba(0,0,0,.0196078431);cursor:default}.sidebar .sidebar-content .active .item-title.open[data-v-09ca60c8]{display:unset;color:var(--color-main)}.background-theme[data-v-e5f51e3c]{background-repeat:no-repeat;background-size:cover;background-position:center}.navbar[data-v-e5f51e3c]{display:flex;flex:1;justify-content:space-between;align-items:center;box-shadow:0 0 100px #00000005;height:48px;padding:0 16px;z-index:2}.navbar.background[data-v-e5f51e3c]{background:rgba(255,255,255,.8)}.left-side[data-v-e5f51e3c]{display:flex;flex-direction:row;align-items:center;gap:24px}.logo-image[data-v-e5f51e3c]{max-height:30px;object-fit:contain}.brand[data-v-e5f51e3c]{display:flex;flex-direction:row;align-items:center;justify-content:center;gap:20px}.brand .brand-name[data-v-e5f51e3c]{color:#49454f;font-weight:400;font-size:16px;line-height:24px}.signed-email[data-v-e5f51e3c]{display:flex;align-items:center;padding:5px 10px;border-radius:42px;color:#49454f;cursor:default;user-select:none;font-size:14px;font-family:Inter;font-style:normal;font-weight:400;line-height:20px}.signed-email .logout[data-v-e5f51e3c]{margin-left:10px;cursor:pointer}.sidebar-menu-icon[data-v-e5f51e3c]{cursor:pointer;width:24px;height:24px;border-radius:8px}@media screen and (min-width: 1200px){.sidebar-menu-icon.dash[data-v-e5f51e3c]:not(.desktop){display:none}}.sidebar-menu-icon.dash.mobile[data-v-e5f51e3c]{display:unset}
