import{v as r}from"./icons.778999cd.js";import{d as p,J as u,H as _,a as i,b as l,c as d,e as m,z as v,S as h,q as f}from"./registerWidgets.88d12ae1.js";const w=p({__name:"PreviewButton",props:{model:null},setup(t){const e=t,n=u(),s=_(),c=()=>{const o=n.query;s.push({path:`/_editor/${e.model.routeName}/${encodeURIComponent(e.model.path)}/preview`,query:o})};return(o,b)=>{const a=i("icon");return l(),d("button",{class:"preview-button",onClick:c},[m(a,{class:"icon",path:v(r),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),h(" Preview ")])}}});const B=f(w,[["__scopeId","data-v-4b4c109d"]]);export{B as P};
//# sourceMappingURL=PreviewButton.31dce115.js.map
