import{L as o}from"./lottie.b93b14fe.js";import{d as t,r,o as d,b as s,c as i,x as c,B as _,q as l}from"./registerWidgets.ef15081f.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="3adf182a-300b-49ea-9826-69923cdb74f1",n._sentryDebugIdIdentifier="sentry-dbid-3adf182a-300b-49ea-9826-69923cdb74f1")}catch{}})();const u={class:"container"},f=t({__name:"LoadingIndicator",setup(n){const e=r(null);return d(()=>{!e.value||o.loadAnimation({container:e.value,renderer:"svg",loop:!0,autoplay:!0,path:"/circularLoading.json"})}),(a,p)=>(s(),i("div",u,[c("div",{ref_key:"animation",ref:e,class:"animation"},null,512),_(a.$slots,"default",{},void 0,!0)]))}});const g=l(f,[["__scopeId","data-v-c30401d8"]]);export{g as L};
//# sourceMappingURL=LoadingIndicator.1e0c6354.js.map
