import{q as r,a,b as i,t as c,f as d,g as p,_,h as u,k as f,T as l,P as h,C as b,M as g,s as y,i as m,j as s,l as w,m as v,n as k}from"./registerWidgets.9f96e537.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="af1acb7d-7b4c-41b0-84d1-8fe287558190",e._sentryDebugIdIdentifier="sentry-dbid-af1acb7d-7b4c-41b0-84d1-8fe287558190")}catch{}})();const I={};function x(e,t){const o=a("router-view");return i(),c(o,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=r(I,[["render",x]]),n=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.eda6e575.js"),["assets/Player.eda6e575.js","assets/index.2a31702d.js","assets/registerWidgets.9f96e537.js","assets/registerWidgets.448db7e9.css","assets/log.0cea70fb.js","assets/broker.458b5417.js","assets/passwordlessManager.5f237f08.js","assets/icons.4255d62c.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.9754ad47.js","assets/Passwordless.89fc3fc4.js","assets/CircularLoading.c1f8d14a.js","assets/lottie.2c3db159.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/executeJs.de5bda16.js","assets/PlayerNavbar.6a5e884d.js","assets/PlayerNavbar.1542e7ca.css","assets/WidgetsFrame.7e615d48.js","assets/colors.b5e37374.js","assets/WidgetsFrame.701a818b.css","assets/Modal.add412a5.js","assets/Modal.5aaf8eba.css","assets/executeJs.b0d1ede9.css","assets/broker.f87ad36d.css","assets/DashPlayer.51da8284.js","assets/runnerData.8f64ea72.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.0a45b9d8.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=u({render:()=>f(A)});l.init(),e.use(n),e.use(h),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",g),e.component("Message",y),m(e,n),s(e,w),s(e,v),s(e,k)};D();
//# sourceMappingURL=player.f3e73dd9.js.map
