import{q as t,b as s,c as o}from"./registerWidgets.ad696c68.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="124601d8-a078-43bc-b053-2692d32955e8",e._sentryDebugIdIdentifier="sentry-dbid-124601d8-a078-43bc-b053-2692d32955e8")}catch{}})();const r={},d={class:"organization-settings"};function i(e,n){return s(),o("div",d,"Organization settings")}const f=t(r,[["render",i]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.5224383b.js.map
