import{d as v,K as D,b as u,c as g,z as t,t as p,D as c,F as w,J as k,H as b,q as I}from"./registerWidgets.68572380.js";import{D as P,n as q}from"./DashPlayer.1858f538.js";import{L as x}from"./CircularLoading.30fd4d73.js";import{r as B}from"./index.23f9da39.js";import{B as R}from"./BackButton.b8e69812.js";import{a as l}from"./asyncComputed.896b7bde.js";import{D as C}from"./dashes.d2191afe.js";import{W as F}from"./workspaces.6e8c216b.js";import"./passwordlessManager.8fb0aebd.js";import"./runnerData.09d29411.js";import"./executeJs.00514c74.js";import"./PlayerNavbar.b0c1c386.js";import"./icons.3acf9dc1.js";import"./WidgetsFrame.b4601d67.js";import"./colors.5f5bc2fa.js";import"./Modal.dacb9a40.js";import"./log.13038e9d.js";import"./Passwordless.6c7a116b.js";import"./lottie.e503152f.js";import"./activeRecord.15082700.js";(function(){try{var s=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(s._sentryDebugIds=s._sentryDebugIds||{},s._sentryDebugIds[r]="80fc90d7-768e-4768-bd33-135fc5c66758",s._sentryDebugIdIdentifier="sentry-dbid-80fc90d7-768e-4768-bd33-135fc5c66758")}catch{}})();const E=v({__name:"DashPreview",setup(s){const r=k(),o=b(),m=({id:e,type:n})=>{n==="dash"?(o.push({name:"dashPreview",params:{dashId:e},query:r.query}),h()):o.push({name:"form-preview",params:{formId:e},query:r.query})},f=()=>{var e;!((e=a.value)!=null&&e.path)||o.push(`/_editor/dash/${encodeURIComponent(a.value.path)}`)},{loading:y,result:a,refetch:h}=l(()=>C.get(r.params.dashPath)),{result:d}=l(()=>F.get()),i=D(()=>{if(!a.value||!d.value||!a.value.makeRunnerData(d.value))return null;const e=q.create(a.value.makeRunnerData(d.value),!1);return e.onRedirect(({url:n,queryParams:_})=>B(o,n,_)),e});return(e,n)=>(u(),g(w,null,[t(y)||!t(a)?(u(),p(x,{key:0,class:"loading",justify:"center"})):c("",!0),t(i)?(u(),p(P,{key:1,class:"player",dash:t(i).runnerData,"is-preview":!0,params:t(r).query,"dash-player-state":t(i),onNavigate:m},null,8,["dash","params","dash-player-state"])):c("",!0),t(a)?(u(),p(R,{key:2,onExitFullscreenPreview:f})):c("",!0)],64))}});const Z=I(E,[["__scopeId","data-v-dde58483"]]);export{Z as default};
//# sourceMappingURL=DashPreview.0e05b2a9.js.map
