import{d as _,K as i,b,c as g,e as s,z as c,x as l,F as v,J as f,a as y,q as h}from"./registerWidgets.e8bf9be7.js";import{a as p}from"./asyncComputed.15c1fcc9.js";import{P as I}from"./project.6241f860.js";import"./gateway.52ae1994.js";import{O as j}from"./organization.c81ec540.js";import{N as z}from"./Navbar.1ac45df5.js";import{S as w}from"./Sidebar.ac226259.js";import{I as P,E as k,J as x,K as B,L as $,F as D,G as E,H as N}from"./icons.d2d6a2d6.js";import"./activeRecord.66fd8f56.js";import"./passwordlessManager.22684bfc.js";import"./logo.084e5d7c.js";import"./Tooltip.19e5bad5.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[o]="85d1f356-2540-4e3c-a718-97ea98481ce1",a._sentryDebugIdIdentifier="sentry-dbid-85d1f356-2540-4e3c-a718-97ea98481ce1")}catch{}})();const S={class:"project"},C={class:"content-wrapper"},F=_({__name:"Project",setup(a){const r=f().params.projectId,{result:e}=p(()=>I.get(r)),{result:t}=p(()=>e.value?j.get(e.value.organizationId):Promise.resolve(null)),m=i(()=>{var n;return t.value&&e.value?[{label:(n=t.value)==null?void 0:n.name,path:`/organizations/${t.value.id}`},{label:e.value.name,path:`/projects/${e.value.id}`}]:void 0}),d=i(()=>e.value?[{name:"Project",items:[{name:"Builds",path:"builds",icon:P},{name:"API Keys",path:"api-keys",icon:k},{name:"Env Vars",path:"env-vars",icon:x},{name:"Logs",icon:B,path:"logs",beta:!0},{name:"Settings",icon:$,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:D,path:`/organizations/${e.value.organizationId}/projects`},{name:"Members",icon:E,path:`/organizations/${e.value.organizationId}/members`},{name:"Billing",icon:N,path:`/organizations/${e.value.organizationId}/billing`,unavailable:!0}]}]:[]);return(n,K)=>{const u=y("router-view");return b(),g(v,null,[s(z,{class:"nav",breadcrumb:c(m)},null,8,["breadcrumb"]),l("div",S,[s(w,{class:"sidebar",sections:c(d)},null,8,["sections"]),l("div",C,[s(u)])])],64)}}});const U=h(F,[["__scopeId","data-v-cfb4011f"]]);export{U as default};
//# sourceMappingURL=Project.41ff538d.js.map
