import{d as u,K as f,b as y,t as g,z as s,J as _}from"./registerWidgets.68572380.js";import{a as w}from"./asyncComputed.896b7bde.js";import"./gateway.7cd64c5e.js";import{M as i}from"./member.cfc3d34b.js";import"./index.5601bb74.js";import{C as I}from"./CrudView.22ff1852.js";import"./passwordlessManager.8fb0aebd.js";import"./activeRecord.15082700.js";import"./DropdownMenu.06bbb53d.js";import"./Modal.dacb9a40.js";import"./LoadingIndicator.5fb5b875.js";import"./lottie.e503152f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="b500a84e-403e-408d-8c33-71c1edb2b03c",e._sentryDebugIdIdentifier="sentry-dbid-b500a84e-403e-408d-8c33-71c1edb2b03c")}catch{}})();const J=u({__name:"Members",setup(e){const a=_().params.organizationId,m=[{key:"email",label:"Email"}],l=async t=>{await i.create(a,t.email),p()},{loading:d,result:c,refetch:p}=w(()=>i.list(a)),b=f(()=>{var t,r;return{columns:[{name:"Email"},{name:"Role"}],rows:(r=(t=c.value)==null?void 0:t.map(n=>({key:n.email,cells:[{text:n.email,classes:["title","centered"]},{text:n.role,classes:["centered"]}]})))!=null?r:[]}});return(t,r)=>(y(),g(I,{"entity-name":"members",loading:s(d),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:s(b),"create-button-text":"Add members",fields:m,onCreate:l},null,8,["loading","table"]))}});export{J as default};
//# sourceMappingURL=Members.e30a0caf.js.map
