import{S as c}from"./Sidebar.3fdcf802.js";import{N as m}from"./Navbar.26cae9cb.js";import{F as l,G as p,H as u}from"./icons.8b9604eb.js";import{d as b,K as _,b as f,c as g,e as t,z as r,x as v,F as y,J as z,a as w,q as I}from"./registerWidgets.1590c05e.js";import{a as h}from"./asyncComputed.0f7a44c1.js";import"./gateway.d26fa955.js";import{O}from"./organization.ce418f68.js";import"./Tooltip.aadfca92.js";import"./logo.084e5d7c.js";import"./passwordlessManager.e40e91a8.js";import"./activeRecord.e76d7c5c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="d92ad962-26d5-457b-b8da-14a44eac84d7",e._sentryDebugIdIdentifier="sentry-dbid-d92ad962-26d5-457b-b8da-14a44eac84d7")}catch{}})();const x={class:"organization"},k=b({__name:"Organization",setup(e){const n=z().params.organizationId,{result:o}=h(()=>O.get(n)),s=_(()=>o.value?[{label:o.value.name,path:`/organizations/${o.value.id}`}]:void 0),i=[{name:"Organization",items:[{name:"Projects",icon:l,path:"projects"},{name:"Members",icon:p,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(B,D)=>{const d=w("router-view");return f(),g(y,null,[t(m,{breadcrumb:r(s)},null,8,["breadcrumb"]),v("div",x,[t(c,{class:"sidebar",sections:r(i)},null,8,["sections"]),t(d)])],64)}}});const J=I(k,[["__scopeId","data-v-7eef90b7"]]);export{J as default};
//# sourceMappingURL=Organization.ff831594.js.map
