import{d as u,K as b,b as y,t as g,z as s,J as _}from"./registerWidgets.dc0b6768.js";import{a as w}from"./asyncComputed.1ef6bcd7.js";import"./gateway.320dd104.js";import{M as i}from"./member.bbc60acc.js";import{C as I}from"./CrudView.22658196.js";import"./passwordlessManager.914ef4f9.js";import"./activeRecord.81c73286.js";import"./DropdownMenu.f0c8b270.js";import"./Modal.cf860ea9.js";import"./LoadingIndicator.91ee9d3a.js";import"./lottie.eb38a9e8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="f0422af9-c833-428c-8fbc-a1c788a260e9",e._sentryDebugIdIdentifier="sentry-dbid-f0422af9-c833-428c-8fbc-a1c788a260e9")}catch{}})();const A=u({__name:"Members",setup(e){const o=_().params.organizationId,m=[{key:"email",label:"Email"}],l=async t=>{await i.create(o,t.email),f()},{loading:c,result:d,refetch:f}=w(()=>i.list(o)),p=b(()=>{var t,r;return{columns:[{name:"Email"},{name:"Role"}],rows:(r=(t=d.value)==null?void 0:t.map(n=>({key:n.email,cells:[{text:n.email,classes:["title","centered"]},{text:n.role,classes:["centered"]}]})))!=null?r:[]}});return(t,r)=>(y(),g(I,{"entity-name":"members",loading:s(c),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:s(p),"create-button-text":"Add members",fields:m,onCreate:l},null,8,["loading","table"]))}});export{A as default};
//# sourceMappingURL=Members.895b11c0.js.map
