.table-settings[data-v-5812aa88]{width:960px;max-width:calc(100vw - 40px);padding:50px 0;align-self:center;display:flex;flex-direction:column;gap:10px}.table-settings .table-field[data-v-5812aa88]{display:flex}.table-settings .table-field .table-name[data-v-5812aa88]{border:1px solid #ccc;border-radius:5px;padding:5px 10px;font-size:16px;outline:none;transition:border-color .2s ease-in-out;flex-grow:1}.table-settings .table-field .table-name[data-v-5812aa88]:focus{border-color:#aaa}.table-settings .table-field .table-name[data-v-5812aa88]:hover{border-color:#8e8e8e}.table-settings .columns[data-v-5812aa88]{display:flex;flex-direction:column;gap:10px}.table-settings .columns .column[data-v-5812aa88]{display:flex;align-items:center;gap:5px}.table-settings .columns .column .column-name[data-v-5812aa88],.table-settings .columns .column .column-default[data-v-5812aa88]{border:1px solid #ccc;border-radius:5px;padding:5px 10px;font-size:16px;outline:none;transition:border-color .2s ease-in-out;flex-grow:1;flex-basis:0}.table-settings .columns .column .column-name[data-v-5812aa88]:focus,.table-settings .columns .column .column-default[data-v-5812aa88]:focus{border-color:#aaa}.table-settings .columns .column .column-name[data-v-5812aa88]:hover,.table-settings .columns .column .column-default[data-v-5812aa88]:hover{border-color:#8e8e8e}.table-settings .columns .column .column-type[data-v-5812aa88]{border:1px solid #ccc;border-radius:5px;padding:5px 10px;font-size:16px;outline:none;transition:border-color .2s ease-in-out}.table-settings .columns .column .column-type[data-v-5812aa88]:focus{border-color:#aaa}.table-settings .columns .column .column-type[data-v-5812aa88]:hover{border-color:#8e8e8e}.table-settings .button[data-v-5812aa88]{border:none;border-radius:5px;cursor:pointer;display:flex;align-items:center;justify-content:center;color:#8e8e8e;text-transform:uppercase}.table-settings .button.save.disabled[data-v-5812aa88]{opacity:.5;cursor:initial}:root{--main-font-family: DM Sans, sans-serif}:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel{background-color:#fff;padding:10px}.table-data{width:960px;max-width:calc(100vw - 40px);padding:50px 0;align-self:center}.table-data .add-row{padding:10px 20px;border:1px solid #ccc;border-radius:5px;font-size:16px;cursor:pointer;background-color:#fff}.table-data .add-row:hover{background-color:#eee}.table-data table{border-collapse:collapse;min-width:100%}.table-data table thead th{padding:.5em;border-bottom:1px solid #ddd}.table-data table thead .column-header{display:flex;justify-content:space-between}.table-data table thead .column-header .column-name{font-weight:700}.table-data table tbody tr td{padding:.5em;border-bottom:1px solid #ddd}.table-data table tbody tr:hover{background-color:#eee}.table-data table tbody tr .delete-row{cursor:pointer}.table-data .editing-row-container{top:50%;transform:translateY(-50%)}.table-data .editing-row-container .editing-row-content{display:flex;flex-direction:column;gap:10px}.table-data .editing-row-container .editing-row-content .editing-row-header{display:flex;justify-content:space-between;font-weight:700}.table-data .editing-row-container .editing-row-content .editing-row-header .close{cursor:pointer}.table-data .editing-row-container .editing-row-content .column{display:flex;flex-direction:column}.table-data .editing-row-container .editing-row-content .column input{border:1px solid #ccc;border-radius:5px;padding:5px 10px;font-size:16px}.table-data .editing-row-container .editing-row-content .button{cursor:pointer;display:flex;flex-direction:row;justify-content:center;align-items:center;padding:8px 20px;gap:10px;border:none;border-radius:4px;font-family:DM Sans,sans-serif;text-decoration:none;background:#d14056;color:#fff;box-shadow:0 2px 4px #00000026}.table-data .editing-row-container .editing-row-content .button:hover{background:#e55b70;box-shadow:0 4px 12px #00000026}.table-data .editing-row-container .editing-row-content .button:active,.table-data .editing-row-container .editing-row-content .button active{background:#e55b70;box-shadow:inset 0 4px 4px #0000000f}.table-data .editing-row-container .editing-row-content .row-error{color:red}.table-connect .connect-example[data-v-0b54f9e9]{white-space:normal}
