import{S as d}from"./Sidebar.698020b7.js";import{N as m}from"./Navbar.03b5b117.js";import{F as l,G as p,H as u}from"./icons.3acf9dc1.js";import{d as b,K as _,b as f,c as g,e as t,z as r,x as v,F as y,J as z,a as w,q as I}from"./registerWidgets.68572380.js";import{a as h}from"./asyncComputed.896b7bde.js";import"./gateway.7cd64c5e.js";import{O}from"./organization.9b0cf47a.js";import"./index.5601bb74.js";import"./Tooltip.4f102cfe.js";import"./logo.084e5d7c.js";import"./passwordlessManager.8fb0aebd.js";import"./activeRecord.15082700.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="adda43c7-bb67-4f1f-a7e7-8a8a91f19230",e._sentryDebugIdIdentifier="sentry-dbid-adda43c7-bb67-4f1f-a7e7-8a8a91f19230")}catch{}})();const x={class:"organization"},k=b({__name:"Organization",setup(e){const n=z().params.organizationId,{result:o}=h(()=>O.get(n)),s=_(()=>o.value?[{label:o.value.name,path:`/organizations/${o.value.id}`}]:void 0),i=[{name:"Organization",items:[{name:"Projects",icon:l,path:"projects"},{name:"Members",icon:p,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(B,D)=>{const c=w("router-view");return f(),g(y,null,[t(m,{breadcrumb:r(s)},null,8,["breadcrumb"]),v("div",x,[t(d,{class:"sidebar",sections:r(i)},null,8,["sections"]),t(c)])],64)}}});const K=I(k,[["__scopeId","data-v-7eef90b7"]]);export{K as default};
//# sourceMappingURL=Organization.75e049c4.js.map
