import{L as o}from"./lottie.ea647b01.js";import{d as t,r,o as s,b as d,c as i,x as c,B as _,q as l}from"./registerWidgets.05268d5e.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="2ca842b8-7ef0-4ab3-a5d3-0e8072293641",n._sentryDebugIdIdentifier="sentry-dbid-2ca842b8-7ef0-4ab3-a5d3-0e8072293641")}catch{}})();const u={class:"container"},f=t({__name:"LoadingIndicator",setup(n){const e=r(null);return s(()=>{!e.value||o.loadAnimation({container:e.value,renderer:"svg",loop:!0,autoplay:!0,path:"/circularLoading.json"})}),(a,p)=>(d(),i("div",u,[c("div",{ref_key:"animation",ref:e,class:"animation"},null,512),_(a.$slots,"default",{},void 0,!0)]))}});const g=l(f,[["__scopeId","data-v-c30401d8"]]);export{g as L};
//# sourceMappingURL=LoadingIndicator.cd761736.js.map
