import{d as b,v as h,y as g,K as T,o as y,b as o,c,x as _,z as u,B as r,D as p,F as k,L as I,a8 as w,a as D,G as $,t as A,S as C,N as x,q as m,a9 as B,V as S,aa as M}from"./registerWidgets.0a925ff6.js";(function(){try{var s=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(s._sentryDebugIds=s._sentryDebugIds||{},s._sentryDebugIds[e]="ae72632e-38d6-4241-909a-715109cd6775",s._sentryDebugIdIdentifier="sentry-dbid-ae72632e-38d6-4241-909a-715109cd6775")}catch{}})();const N={class:"tab-menu"},V={class:"tabs"},E={key:0,class:"group"},z={class:"group"},F=["onClick"],L={key:1,class:"group"},U={class:"content"},j=b({__name:"TabMenuUnderline",setup(s){const e=h([]),a=g(),d=t=>{const v=i=>i==t;e.forEach((i,n)=>{i.isActive=v(n)})},l=T(()=>e.findIndex(t=>t.isActive));return w("addTab",t=>{e.push(t)}),y(()=>{d(0)}),(t,v)=>{const i=D("icon");return o(),c("div",N,[_("div",V,[u(a).left?(o(),c("div",E,[r(t.$slots,"left",{},void 0,!0)])):p("",!0),_("div",z,[(o(!0),c(k,null,I(e,(n,f)=>(o(),c("button",{key:n.title,class:$(["form-tab",u(l)==f&&"active"]),onClick:K=>d(f)},[n.icon?(o(),A(i,{key:0,path:n.icon,fill:"#8692A5",width:"10",height:"10"},null,8,["path"])):p("",!0),C(" "+x(n.title),1)],10,F))),128))]),u(a).right?(o(),c("div",L,[r(t.$slots,"right",{},void 0,!0)])):p("",!0)]),_("div",U,[r(t.$slots,"default",{},void 0,!0)])])}}});const J=m(j,[["__scopeId","data-v-60b2affa"]]),q={class:"tab"},G=b({__name:"Tab",props:{title:null,icon:null},setup(s){const e=s,a=h({isActive:!1,title:e.title,icon:e.icon}),d=B("addTab");return y(()=>{d(a)}),(l,t)=>S((o(),c("div",q,[r(l.$slots,"default",{},void 0,!0)],512)),[[M,a.isActive]])}});const O=m(G,[["__scopeId","data-v-9c2e92c2"]]);export{J as T,O as a};
//# sourceMappingURL=Tab.a5c9c887.js.map
