import{P as r}from"./Passwordless.8d7065c4.js";import{N as a}from"./Navbar.4fe8df65.js";import{d,b as c,c as i,e as t,H as _,q as p}from"./registerWidgets.6f0bbac2.js";import{M as m}from"./member.07bf274e.js";import"./CircularLoading.64e0c9cf.js";import"./lottie.68b1efe0.js";import"./icons.33d01da0.js";import"./passwordlessManager.643e43e8.js";import"./logo.084e5d7c.js";import"./asyncComputed.e83909df.js";import"./gateway.2f3fe23e.js";import"./activeRecord.9b68dfe2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="3270dc25-7cb2-4e8d-ab8b-d8c89ee9d42f",e._sentryDebugIdIdentifier="sentry-dbid-3270dc25-7cb2-4e8d-ab8b-d8c89ee9d42f")}catch{}})();const f={class:"login"},b=d({__name:"Login",setup(e){const o=_();async function s(n){await m.login(),o.push({name:"home"})}return(n,l)=>(c(),i("div",f,[t(a,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const N=p(b,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.fd740800.js.map
