[data-v-7a49cef6]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}*[data-v-7a49cef6]{padding:0;margin:0}.form[data-v-7a49cef6],.preview[data-v-7a49cef6]{min-height:100vh}.loading[data-v-7a49cef6]{position:absolute;top:0;left:0;width:100vw;height:100vh;display:flex;justify-content:center;align-items:center}.error[data-v-7a49cef6]{display:flex;justify-content:center;align-items:center;flex-direction:column;gap:1rem}.dash-wrapper[data-v-7a49cef6]{display:flex;flex-direction:column;height:100vh}.dash-wrapper .player[data-v-7a49cef6]{flex-grow:1}
