import{p as o,a as r,b as a,q as n,f as i,g as p,_ as c,h as _,j as h,T as u,P as d,C as l,M as m,s as g,i as t,k as v,l as w,m as f}from"./registerWidgets.04dc761e.js";const k={};function y(e,W){const s=r("router-view");return a(),n(s,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const b=o(k,[["render",y]]),x=i({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>c(()=>import("./Player.9f1a865f.js"),["assets/Player.9f1a865f.js","assets/index.6f0d5525.js","assets/registerWidgets.04dc761e.js","assets/registerWidgets.3aec804f.css","assets/log.0073b587.js","assets/broker.4829432d.js","assets/passwordlessManager.271a8058.js","assets/icons.d4e872e2.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.c4424b2b.js","assets/Passwordless.0107ba48.js","assets/CircularLoading.78e37a70.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/executeJs.740555ed.js","assets/PlayerNavbar.c204244e.js","assets/PlayerNavbar.1542e7ca.css","assets/WidgetsFrame.e00c0ab1.js","assets/WidgetsFrame.cf328b77.css","assets/Modal.02341c49.js","assets/Modal.5aaf8eba.css","assets/executeJs.b0d1ede9.css","assets/broker.7a2eb540.css","assets/DashPlayer.79dbd8c0.js","assets/runnerData.91239e67.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.e0f43af3.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),A=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=_({render:()=>h(b)});u.init(),e.use(x),e.use(d),e.mount("#app"),e.component("VSelect",l),e.component("Markdown",m),e.component("Message",g),t(e,v),t(e,w),t(e,f)};A();
//# sourceMappingURL=player.0ff4272c.js.map
