import{q as t,b as s,c as o}from"./registerWidgets.39370cce.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="64dcb8e3-1f36-41e8-9cf7-355b8449f0b6",e._sentryDebugIdIdentifier="sentry-dbid-64dcb8e3-1f36-41e8-9cf7-355b8449f0b6")}catch{}})();const r={},c={class:"organization-settings"};function i(e,n){return s(),o("div",c,"Organization settings")}const a=t(r,[["render",i]]);export{a as default};
//# sourceMappingURL=OrganizationSettings.2bbac0f6.js.map
