import{d as r,r as f,o as i,a3 as l,b as u,c,N as b,ad as y}from"./registerWidgets.ad696c68.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="cff299da-f226-46fa-bdad-2929e5786ab9",e._sentryDebugIdIdentifier="sentry-dbid-cff299da-f226-46fa-bdad-2929e5786ab9")}catch{}})();const g=r({__name:"ActionButton",props:{action:null},emits:["next"],setup(e,{emit:n}){const o=e,a=f(null);i(()=>{a.value&&o.action.setElement(a.value),l.addAction(o.action)});const s=()=>n("next");return(m,t)=>(u(),c("button",{ref_key:"element",ref:a,class:"next-button",onClick:t[0]||(t[0]=d=>s()),onKeydown:t[1]||(t[1]=y(d=>s(),["enter"]))},b(e.action.name),545))}});export{g as _};
//# sourceMappingURL=ActionButton.vue_vue_type_script_setup_true_lang.a0f7f94d.js.map
