import{P as a}from"./Passwordless.1696a947.js";import{N as r}from"./Navbar.60d8d8eb.js";import{d as n,b as _,c,e as o,H as i,q as p}from"./registerWidgets.81004098.js";import{M as m}from"./member.cdefe71a.js";import"./CircularLoading.cef8a22f.js";import"./icons.ea1ef9e9.js";import"./passwordlessManager.d8088db9.js";import"./logo.084e5d7c.js";import"./utils.ac5c1175.js";import"./pubsub.a0411919.js";const d={class:"login"},l=n({__name:"Login",setup(u){const e=i();async function s(t){await m.login(),e.push({name:"home"})}return(t,f)=>(_(),c("div",d,[o(r,{class:"nav"}),o(a,{class:"passwordless",onDone:s})]))}});const k=p(l,[["__scopeId","data-v-21777ab7"]]);export{k as default};
//# sourceMappingURL=Login.97595a2b.js.map
