import{L as t}from"./lottie.a6ae83a3.js";import{d as a,r,o as s,b as d,c as i,x as c,B as _,q as l}from"./registerWidgets.0a925ff6.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="6798f66c-792e-4f04-8a8b-63600c9082e6",n._sentryDebugIdIdentifier="sentry-dbid-6798f66c-792e-4f04-8a8b-63600c9082e6")}catch{}})();const u={class:"container"},f=a({__name:"LoadingIndicator",setup(n){const e=r(null);return s(()=>{!e.value||t.loadAnimation({container:e.value,renderer:"svg",loop:!0,autoplay:!0,path:"/circularLoading.json"})}),(o,p)=>(d(),i("div",u,[c("div",{ref_key:"animation",ref:e,class:"animation"},null,512),_(o.$slots,"default",{},void 0,!0)]))}});const m=l(f,[["__scopeId","data-v-c30401d8"]]);export{m as L};
//# sourceMappingURL=LoadingIndicator.1acdfc35.js.map
