import{P as l}from"./PlayerNavbar.94c81143.js";import{d as i}from"./runnerData.18839000.js";import{d as m,K as d,b as c,c as p,x as u,z as t,t as k,D as _,A as b,q as w}from"./registerWidgets.4a0d8d45.js";const y={class:"sidebar-preview"},f=m({__name:"SidebarPreview",props:{workspace:null},setup(a){const e=a,r=d(()=>{var o,s;return e.workspace?{id:"mockId",path:"mockPath",title:"mockTitle",theme:e.workspace.theme,brandName:(o=e.workspace.brandName)!=null?o:null,logoUrl:(s=e.workspace.logoUrl)!=null?s:null,mainColor:e.workspace.mainColor,fontFamily:e.workspace.fontFamily,layout:i({props:{},slot:{},version:"0.2"}),idOrPath:"mockIdOrPath",workspaceName:"Untitled Workspace",sidebar:e.workspace.sidebar,runtimeType:"dash"}:null});return(o,s)=>{var n;return c(),p("div",y,[u("div",{class:"sidebar-frame",style:b({background:(n=t(r))==null?void 0:n.theme})},[t(r)?(c(),k(l,{key:0,runtime:t(r),"display-sidebar":!0,"brand-name":a.workspace.brandName,"logo-url":a.workspace.logoUrl,"user-email":"user@email.com","force-responsivity":"desktop"},null,8,["runtime","brand-name","logo-url"])):_("",!0)],4)])}}});const g=w(f,[["__scopeId","data-v-aad4556c"]]);export{g as S};
//# sourceMappingURL=SidebarPreview.21eceea3.js.map
