import{P as a}from"./Passwordless.ad2f56fc.js";import{N as r}from"./Navbar.7e9e7647.js";import{d as n,b as _,c as i,e as o,H as p,q as c}from"./registerWidgets.69eb7b40.js";import{M as m}from"./member.57bf3e31.js";import"./CircularLoading.3c5929bd.js";import"./icons.ea1ef9e9.js";import"./passwordlessManager.3c745f80.js";import"./logo.084e5d7c.js";import"./asyncComputed.5c8fd07f.js";import"./utils.7963b0ba.js";import"./pubsub.a0411919.js";const d={class:"login"},l=n({__name:"Login",setup(f){const e=p();async function s(t){await m.login(),e.push({name:"home"})}return(t,u)=>(_(),i("div",d,[o(r,{class:"nav"}),o(a,{class:"passwordless",onDone:s})]))}});const B=c(l,[["__scopeId","data-v-64286f28"]]);export{B as default};
//# sourceMappingURL=Login.b8393426.js.map
