import{P as a}from"./Passwordless.41457a61.js";import{N as r}from"./Navbar.3d36e674.js";import{d,b as i,c,e as t,H as _,q as p}from"./registerWidgets.f021c1a4.js";import{M as f}from"./member.58abb3a0.js";import"./CircularLoading.403df380.js";import"./lottie.61fc86ea.js";import"./icons.b993259e.js";import"./passwordlessManager.60015512.js";import"./logo.084e5d7c.js";import"./asyncComputed.99b3d376.js";import"./gateway.d0ae64bf.js";import"./activeRecord.ae1eba97.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="4ce7a262-eb3f-476a-9ad7-8d78da3f1c20",e._sentryDebugIdIdentifier="sentry-dbid-4ce7a262-eb3f-476a-9ad7-8d78da3f1c20")}catch{}})();const m={class:"login"},l=d({__name:"Login",setup(e){const o=_();async function s(n){await f.login(),o.push({name:"home"})}return(n,u)=>(i(),c("div",m,[t(r,{class:"nav"}),t(a,{class:"passwordless",onDone:s})]))}});const N=p(l,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.2acb2e33.js.map
