import{d as v,K as D,b as u,c as g,z as t,t as d,D as l,F as w,J as b,H as k,q as I}from"./registerWidgets.726232df.js";import{D as P,n as q}from"./DashPlayer.170f6ab0.js";import{L as x}from"./CircularLoading.4a9d4906.js";import{r as B}from"./index.bbe106e1.js";import{B as R}from"./BackButton.cc22a97e.js";import{a as m}from"./asyncComputed.638ec138.js";import{D as C}from"./dashes.95090585.js";import{W as F}from"./workspaces.400dc385.js";import"./passwordlessManager.3b0f9bd3.js";import"./runnerData.99da771c.js";import"./executeJs.209fa4e7.js";import"./PlayerNavbar.1086bae4.js";import"./icons.f7969917.js";import"./WidgetsFrame.76941521.js";import"./colors.ad792a0e.js";import"./Modal.bd7677ba.js";import"./log.bef1eaa6.js";import"./Passwordless.72b053f6.js";import"./lottie.1c3b7cde.js";import"./activeRecord.acbdb8bc.js";(function(){try{var s=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(s._sentryDebugIds=s._sentryDebugIds||{},s._sentryDebugIds[a]="077767c2-0fa3-4788-82b4-1e33207ee1bf",s._sentryDebugIdIdentifier="sentry-dbid-077767c2-0fa3-4788-82b4-1e33207ee1bf")}catch{}})();const E=v({__name:"DashPreview",setup(s){const a=b(),o=k(),c=({id:e,type:n})=>{n==="dash"?(o.push({name:"dashPreview",params:{dashId:e},query:a.query}),h()):o.push({name:"form-preview",params:{formId:e},query:a.query})},f=()=>{var e;!((e=r.value)!=null&&e.path)||o.push(`/_editor/dash/${encodeURIComponent(r.value.path)}`)},{loading:y,result:r,refetch:h}=m(()=>C.get(a.params.dashPath)),{result:i}=m(()=>F.get()),p=D(()=>{if(!r.value||!i.value||!r.value.makeRunnerData(i.value))return null;const e=q.create(r.value.makeRunnerData(i.value),!1);return e.onRedirect(({url:n,queryParams:_})=>B(o,n,_)),e});return(e,n)=>(u(),g(w,null,[t(y)||!t(r)?(u(),d(x,{key:0,class:"loading",justify:"center"})):l("",!0),t(p)?(u(),d(P,{key:1,class:"player",dash:t(p).runnerData,"is-preview":!0,params:t(a).query,"dash-player-state":t(p),onNavigate:c},null,8,["dash","params","dash-player-state"])):l("",!0),t(r)?(u(),d(R,{key:2,onExitFullscreenPreview:f})):l("",!0)],64))}});const Z=I(E,[["__scopeId","data-v-dde58483"]]);export{Z as default};
//# sourceMappingURL=DashPreview.e9ae2904.js.map
