import{x as s}from"./icons.35c960d1.js";import{d as r,a as d,b as c,c as i,e as _,z as l,S as f,q as u}from"./registerWidgets.8e2e133d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="dd3ef511-82da-4974-a23a-3e8a295485bf",e._sentryDebugIdIdentifier="sentry-dbid-dd3ef511-82da-4974-a23a-3e8a295485bf")}catch{}})();const p=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(a,n)=>{const o=d("icon");return c(),i("button",{class:"back-btn",onClick:n[0]||(n[0]=b=>t("exitFullscreenPreview"))},[_(o,{class:"icon",path:l(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),f(" Editor ")])}}});const w=u(p,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.db9c9ccb.js.map
