import{P as r}from"./Passwordless.0888f9cc.js";import{N as a}from"./Navbar.e76d5d6b.js";import{d,b as i,c,e as t,H as _,q as p}from"./registerWidgets.0a925ff6.js";import{M as m}from"./member.55112495.js";import"./CircularLoading.63d322f4.js";import"./lottie.a6ae83a3.js";import"./icons.d9ce72d6.js";import"./passwordlessManager.ab5003b1.js";import"./logo.084e5d7c.js";import"./asyncComputed.57718c9c.js";import"./gateway.2d990259.js";import"./activeRecord.ffa40c01.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="8b8e7f96-8cde-47e6-90e9-a840a3b3856d",e._sentryDebugIdIdentifier="sentry-dbid-8b8e7f96-8cde-47e6-90e9-a840a3b3856d")}catch{}})();const f={class:"login"},l=d({__name:"Login",setup(e){const o=_();async function s(n){await m.login(),o.push({name:"home"})}return(n,u)=>(i(),c("div",f,[t(a,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const N=p(l,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.768744ff.js.map
