import{P as r}from"./Passwordless.23bd53e4.js";import{N as a}from"./Navbar.388dd164.js";import{d as i,b as d,c,e as t,H as _,q as p}from"./registerWidgets.0897334f.js";import{M as f}from"./member.ab9b41bd.js";import"./CircularLoading.21f27962.js";import"./lottie.ffe66724.js";import"./icons.74b4bbd7.js";import"./passwordlessManager.1a21d377.js";import"./logo.084e5d7c.js";import"./asyncComputed.14546baa.js";import"./gateway.2c5d8b88.js";import"./activeRecord.6320d31c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="71e0a40d-5c80-44e6-9223-55994fa7f178",e._sentryDebugIdIdentifier="sentry-dbid-71e0a40d-5c80-44e6-9223-55994fa7f178")}catch{}})();const m={class:"login"},l=i({__name:"Login",setup(e){const o=_();async function s(n){await f.login(),o.push({name:"home"})}return(n,u)=>(d(),c("div",m,[t(a,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const N=p(l,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.7feaf094.js.map
