import{q as r,a,b as i,t as c,f as d,g as p,_,h as u,k as l,T as f,P as h,C as b,M as g,s as y,i as m,j as s,l as w,m as v,n as k}from"./registerWidgets.553de467.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="5e4c86e6-b332-4a0d-839a-f4d548e47a6b",e._sentryDebugIdIdentifier="sentry-dbid-5e4c86e6-b332-4a0d-839a-f4d548e47a6b")}catch{}})();const I={};function x(e,t){const o=a("router-view");return i(),c(o,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=r(I,[["render",x]]),n=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.77412bbe.js"),["assets/Player.77412bbe.js","assets/index.1c59a5f6.js","assets/registerWidgets.553de467.js","assets/registerWidgets.a7e6ab4f.css","assets/log.85118ab9.js","assets/broker.c01819c2.js","assets/passwordlessManager.b79493a6.js","assets/icons.012820f9.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.e758ad17.js","assets/Passwordless.84c9704e.js","assets/CircularLoading.01ebf7ca.js","assets/lottie.433e3d0f.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/executeJs.0d5b0965.js","assets/PlayerNavbar.1351341e.js","assets/PlayerNavbar.1542e7ca.css","assets/WidgetsFrame.f5cb9e50.js","assets/colors.ec843c1d.js","assets/WidgetsFrame.701a818b.css","assets/Modal.3622aa4e.js","assets/Modal.5aaf8eba.css","assets/executeJs.b0d1ede9.css","assets/broker.f87ad36d.css","assets/DashPlayer.98e9a361.js","assets/runnerData.9bff4dbf.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.2769eba5.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=u({render:()=>l(A)});f.init(),e.use(n),e.use(h),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",g),e.component("Message",y),m(e,n),s(e,w),s(e,v),s(e,k)};D();
//# sourceMappingURL=player.1c60c044.js.map
