import{q as t,b as s,c as o}from"./registerWidgets.68572380.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="e984eabc-83de-476b-8a7f-df42082b3b07",e._sentryDebugIdIdentifier="sentry-dbid-e984eabc-83de-476b-8a7f-df42082b3b07")}catch{}})();const r={},a={class:"organization-settings"};function d(e,n){return s(),o("div",a,"Organization settings")}const f=t(r,[["render",d]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.4b7308b3.js.map
