import{P as r}from"./Passwordless.f9a4a30d.js";import{N as a}from"./Navbar.26cae9cb.js";import{d,b as i,c as f,e as t,H as c,q as _}from"./registerWidgets.1590c05e.js";import{M as p}from"./member.8fecd57a.js";import"./CircularLoading.30b3ab43.js";import"./lottie.1e0c432a.js";import"./icons.8b9604eb.js";import"./passwordlessManager.e40e91a8.js";import"./logo.084e5d7c.js";import"./asyncComputed.0f7a44c1.js";import"./gateway.d26fa955.js";import"./activeRecord.e76d7c5c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="de7f70d3-ae82-4f6d-8e9a-1e15dbf7f63f",e._sentryDebugIdIdentifier="sentry-dbid-de7f70d3-ae82-4f6d-8e9a-1e15dbf7f63f")}catch{}})();const m={class:"login"},l=d({__name:"Login",setup(e){const o=c();async function s(n){await p.login(),o.push({name:"home"})}return(n,u)=>(i(),f("div",m,[t(a,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const N=_(l,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.880e70a0.js.map
