import{d as P,v as x,r as F,K as R,b as n,c as i,z as e,t as B,e as c,x as I,H as q,J as E,q as D}from"./registerWidgets.39370cce.js";import{L}from"./CircularLoading.858c95df.js";import{E as C}from"./Error.52eebad9.js";import{F as N,R as H}from"./broker.9c02770f.js";import{B as M}from"./BackButton.7d669242.js";import{a as _}from"./asyncComputed.588e6ddd.js";import{F as V}from"./forms.18835248.js";import{W}from"./workspaces.de9440d4.js";import"./lottie.576b6dda.js";import"./passwordlessManager.6cd57365.js";import"./icons.c1d7cae2.js";import"./ActionButton.vue_vue_type_script_setup_true_lang.4f7cca41.js";import"./Passwordless.3318ed89.js";import"./executeJs.3ef70733.js";import"./PlayerNavbar.53686f75.js";import"./index.21ff4977.js";import"./WidgetsFrame.65cd6786.js";import"./colors.9f487a75.js";import"./Modal.664ccd90.js";import"./log.1b415b40.js";import"./activeRecord.fab7288a.js";(function(){try{var s=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(s._sentryDebugIds=s._sentryDebugIds||{},s._sentryDebugIds[t]="09e949c9-bf80-4902-9a09-6b3ce43d6bbc",s._sentryDebugIdIdentifier="sentry-dbid-09e949c9-bf80-4902-9a09-6b3ce43d6bbc")}catch{}})();const z={class:"page"},J={key:1,class:"error"},K={key:2,style:{width:"100%",height:"100%",display:"flex"}},S={style:{width:"100%",height:"100%",display:"flex"}},U=P({__name:"FormPreview",setup(s){const t=q(),r=E(),a=x({started:!1}),m=F(null),{loading:h,result:d,error:u,refetch:p}=_(()=>V.get(r.params.formPath)),{result:f}=_(()=>W.get()),y=R(()=>H.create({isLocal:!1,formPath:r.params.formPath,isPreview:!0})),b=async()=>{var o;if(!a.started){(o=m.value)==null||o.run();return}a.started=!1},v=({path:o,type:l})=>{l==="dash"?t.push({name:"dashPreview",params:{dashPath:o},query:r.query}):(t.push({name:"form-preview",params:{formPath:o},query:r.query}),p())},g=()=>{t.push(`/_editor/form/${encodeURIComponent(r.params.formPath)}`)},w=()=>{a.started=!0},k=()=>{a.started=!1};return(o,l)=>(n(),i("div",z,[e(h)||!e(d)||!e(f)?(n(),B(L,{key:0})):e(u)?(n(),i("div",J,[c(C,{error:e(u),onReload:e(p)},null,8,["error","onReload"])])):(n(),i("main",K,[I("div",S,[c(N,{ref_key:"runner",ref:m,form:e(d).makeRunnerData(e(f)),params:e(r).query,"is-preview":!0,"enable-auto-focus":!0,broker:e(y),style:{height:"unset",flex:1,overflow:"hidden"},onNavigate:v,onLogout:b,onExit:k,onStart:w},null,8,["form","params","broker"]),c(M,{onExitFullscreenPreview:g})])]))]))}});const ue=D(U,[["__scopeId","data-v-f7c2ba13"]]);export{ue as default};
//# sourceMappingURL=FormPreview.9c9cefa6.js.map
