import{q as r,a,b as i,t as c,f as d,g as p,_,h as u,k as l,T as h,P as b,C as f,M as g,s as y,i as m,j as s,l as w,m as v,n as k}from"./registerWidgets.39370cce.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="44d62224-60e0-4c2b-b1da-5bc48639295d",e._sentryDebugIdIdentifier="sentry-dbid-44d62224-60e0-4c2b-b1da-5bc48639295d")}catch{}})();const I={};function x(e,t){const o=a("router-view");return i(),c(o,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=r(I,[["render",x]]),n=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.edde7fb6.js"),["assets/Player.edde7fb6.js","assets/index.21ff4977.js","assets/registerWidgets.39370cce.js","assets/registerWidgets.448db7e9.css","assets/log.1b415b40.js","assets/broker.9c02770f.js","assets/passwordlessManager.6cd57365.js","assets/icons.c1d7cae2.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.4f7cca41.js","assets/Passwordless.3318ed89.js","assets/CircularLoading.858c95df.js","assets/lottie.576b6dda.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/executeJs.3ef70733.js","assets/PlayerNavbar.53686f75.js","assets/PlayerNavbar.1542e7ca.css","assets/WidgetsFrame.65cd6786.js","assets/colors.9f487a75.js","assets/WidgetsFrame.701a818b.css","assets/Modal.664ccd90.js","assets/Modal.5aaf8eba.css","assets/executeJs.b0d1ede9.css","assets/broker.f87ad36d.css","assets/DashPlayer.280ba4ee.js","assets/runnerData.561187a0.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.588e6ddd.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=u({render:()=>l(A)});h.init(),e.use(n),e.use(b),e.mount("#app"),e.component("VSelect",f),e.component("Markdown",g),e.component("Message",y),m(e,n),s(e,w),s(e,v),s(e,k)};D();
//# sourceMappingURL=player.70da382b.js.map
