import{P as a}from"./Passwordless.5d7c0969.js";import{N as r}from"./Navbar.a1669887.js";import{d as n,b as _,c as i,e as o,H as p,q as c}from"./registerWidgets.802bba2f.js";import{M as m}from"./member.d32af91c.js";import"./CircularLoading.5c7f2ad7.js";import"./icons.97625e56.js";import"./passwordlessManager.d5134797.js";import"./logo.084e5d7c.js";import"./asyncComputed.1364aaa9.js";import"./utils.acbba3b4.js";import"./pubsub.a0411919.js";const d={class:"login"},l=n({__name:"Login",setup(f){const e=p();async function s(t){await m.login(),e.push({name:"home"})}return(t,u)=>(_(),i("div",d,[o(r,{class:"nav"}),o(a,{class:"passwordless",onDone:s})]))}});const B=c(l,[["__scopeId","data-v-64286f28"]]);export{B as default};
//# sourceMappingURL=Login.a4d8c07c.js.map
