[data-v-42786fd0]:root{--main-font-family: DM Sans, sans-serif}[data-v-42786fd0]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.save-button[data-v-42786fd0]{font-family:DM Sans,sans-serif;cursor:pointer;display:flex;justify-content:center;align-items:center;gap:6px;padding:7px 14px;height:30px;font-weight:500;font-size:14px;line-height:16px;margin-right:16px;color:#5a677a;border:none;background:transparent;border-radius:5px;border-width:1px;border-color:#5a677a}.save-button.changes[data-v-42786fd0]{border-style:solid;cursor:pointer}.save-button[data-v-42786fd0]:not(.changes){color:#5a677a;border-style:none;opacity:.5}
