[data-v-121cc759]:root{--main-font-family: DM Sans, sans-serif}[data-v-121cc759]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-121cc759]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-121cc759]{background-color:#fff;padding:10px}.logs[data-v-121cc759]{display:flex;flex-direction:column;width:960px;gap:15px;max-width:calc(100vw - 40px);align-self:flex-start;justify-content:start}.logs h1[data-v-121cc759]{font-size:1.5rem;grid-area:title;margin:0;color:#5a677a}.logs .filters[data-v-121cc759]{position:sticky;top:0;z-index:1;background-color:#fff;padding:10px 15px;display:flex;gap:8px}.logs .filters .field[data-v-121cc759]{display:flex;flex-direction:column}.logs .filters .field.field-build[data-v-121cc759]{flex-grow:1}.logs .filters .field label[data-v-121cc759]{font-size:.75rem;color:#5a677a;margin-bottom:5px;line-height:10px}.logs .filters .field input[data-v-121cc759]{border:1px solid #d6d6d6;border-radius:4px;font-size:14px;color:#6d7c93;font-family:DM Sans,sans-serif;outline:none;width:100%;box-sizing:border-box;transition:all .2s ease-in-out;height:35px;padding:0 10px}.logs .filters .field input[data-v-121cc759]:focus{border:1px solid #d14056}.logs .filters .field .build-dropdown[data-v-121cc759]{border:1px solid #d6d6d6;border-radius:4px;padding:8px 12px;font-size:14px;color:#6d7c93;font-family:DM Sans,sans-serif;outline:none;width:100%;box-sizing:border-box;transition:all .2s ease-in-out}.logs .filters .field .build-dropdown[data-v-121cc759]:focus{border:1px solid #d14056}.logs .filters button[data-v-121cc759]{cursor:pointer;display:flex;flex-direction:row;justify-content:center;align-items:center;padding:8px 20px;gap:10px;border:none;border-radius:4px;font-family:DM Sans,sans-serif;text-decoration:none;background:#d14056;color:#fff;box-shadow:0 2px 4px #00000026;align-self:flex-end;margin-bottom:3px}.logs .filters button[data-v-121cc759]:hover{background:#e55b70;box-shadow:0 4px 12px #00000026}.logs .filters button[data-v-121cc759]:active,.logs .filters button active[data-v-121cc759]{background:#e55b70;box-shadow:inset 0 4px 4px #0000000f}.logs .log-list[data-v-121cc759]{display:flex;flex-direction:column}.logs .log-list .search-summary[data-v-121cc759]{font-size:.75rem;color:#5a677a;margin-bottom:10px}.logs .log-list .log[data-v-121cc759]{display:flex;flex-direction:column;border-bottom:1px solid #5a677a}.logs .log-list .log .log-header[data-v-121cc759]{display:flex;background-color:#fff;text-align:center;padding:10px;border-radius:5px;cursor:pointer}.logs .log-list .log .log-header[data-v-121cc759]:hover{background-color:#f5f5f5}.logs .log-list .log .log-header .log-header-item[data-v-121cc759]{display:flex;flex-direction:column;flex-grow:1;align-items:center;justify-content:center;gap:5px;flex-basis:0}.logs .log-list .log .log-header .log-header-item .log-header-item-name[data-v-121cc759]{font-size:.75rem;color:#5a677a;font-weight:700}.logs .log-list .log .log-header .log-header-item .log-header-item-value[data-v-121cc759]{font-size:.75rem;color:#5a677a}.logs .log-list .log .log-payload[data-v-121cc759]{height:500px;overflow:auto;position:relative;background-color:#5a677a;color:#fff}.logs .log-list .log .log-payload .log-payload-content[data-v-121cc759]{position:absolute;padding:15px;top:0;left:0;width:100%;height:100%}
