import{q as o,a as r,b as a,t as n,f as i,g as c,_ as p,h as _,j as h,T as u,P as d,C as l,M as m,s as g,i as t,k as v,l as w,m as f}from"./registerWidgets.88d12ae1.js";const k={};function y(e,W){const s=r("router-view");return a(),n(s,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const b=o(k,[["render",y]]),x=i({history:c("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>p(()=>import("./Player.65a5655b.js"),["assets/Player.65a5655b.js","assets/index.ae3415a0.js","assets/registerWidgets.88d12ae1.js","assets/registerWidgets.a7e6ab4f.css","assets/log.d8fc5146.js","assets/broker.6483aa8d.js","assets/passwordlessManager.a5c71e7e.js","assets/icons.778999cd.js","assets/Passwordless.a5311b67.js","assets/CircularLoading.0c459b72.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/WidgetsFrame.0c34a010.js","assets/colors.4ea7d5a7.js","assets/colors.89be930f.css","assets/Modal.f14dcc44.js","assets/Modal.5aaf8eba.css","assets/WidgetsFrame.47145056.css","assets/broker.f87ad36d.css","assets/DashPlayer.012c8c7f.js","assets/runnerData.833eed88.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.0bf661db.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),A=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=_({render:()=>h(b)});u.init(),e.use(x),e.use(d),e.mount("#app"),e.component("VSelect",l),e.component("Markdown",m),e.component("Message",g),t(e,v),t(e,w),t(e,f)};A();
//# sourceMappingURL=player.9c73b879.js.map
