import{x as a}from"./icons.99afd58c.js";import{d as r,a as c,b as d,c as i,e as _,z as f,S as l,q as u}from"./registerWidgets.fce18b61.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="fb6f376f-4018-4d3b-9d07-9535c5358937",e._sentryDebugIdIdentifier="sentry-dbid-fb6f376f-4018-4d3b-9d07-9535c5358937")}catch{}})();const p=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const s=c("icon");return d(),i("button",{class:"back-btn",onClick:n[0]||(n[0]=b=>t("exitFullscreenPreview"))},[_(s,{class:"icon",path:f(a),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),l(" Editor ")])}}});const w=u(p,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.f77362f6.js.map
